@@ -486,7 +486,7 @@ private:
 public:
     // CONSTRUCTORS
     explicit CaseVisitor(AstNetlist* nodep) {
-        for (uint32_t i = 0; i < (1UL << CASE_OVERLAP_WIDTH); ++i) m_valueItem[i] = nullptr;
+        for (auto& itr : m_valueItem) itr = nullptr;
         iterate(nodep);
     }
     virtual ~CaseVisitor() override {
