@@ -311,13 +311,12 @@ private:
         }
     }
 
-    string spaces(int level) {
+    static string spaces(int level) {
         string out;
         while (level--) out += " ";
         return out;
     }  // LCOV_EXCL_LINE
-
-    string pad(unsigned column, const string& in) {
+    static string pad(unsigned column, const string& in) {
         string out = in;
         while (out.length() < column) out += ' ';
         return out;
@@ -588,15 +587,15 @@ private:
         // Convert list of senses into one sense node
         AstSenTree* senoutp = nullptr;
         bool senedited = false;
-        for (SenSet::iterator it = senouts.begin(); it != senouts.end(); ++it) {
+        for (const auto& itr : senouts) {
             if (!senoutp) {
-                senoutp = *it;
+                senoutp = itr;
             } else {
                 if (!senedited) {
                     senedited = true;
                     senoutp = senoutp->cloneTree(true);
                 }
-                senoutp->addSensesp((*it)->sensesp()->cloneTree(true));
+                senoutp->addSensesp(itr->sensesp()->cloneTree(true));
             }
         }
         // If multiple domains need to do complicated optimizations
@@ -661,7 +660,7 @@ private:
             // We use weight of one for normal edges,
             // Weight of CDC_WEIGHT_ASYNC to indicate feeds async (for reporting)
             // When simplify we'll take the MAX weight
-            if (nodep->lvalue()) {
+            if (nodep->access().isWriteOrRW()) {
                 new V3GraphEdge(&m_graph, m_logicVertexp, varvertexp, 1);
                 if (m_inDly) {
                     varvertexp->fromFlop(true);
