@@ -65,6 +65,10 @@ public:
         of.puts("VM_TRACE = ");
         of.puts(v3Global.opt.trace() ? "1" : "0");
         of.puts("\n");
+        of.puts("# Tracing output mode in FST format?  0/1 (from --trace-fst)\n");
+        of.puts("VM_TRACE_FST = ");
+        of.puts(v3Global.opt.trace() && v3Global.opt.traceFormat().fst() ? "1" : "0");
+        of.puts("\n");
         of.puts("# Tracing threaded output mode?  0/1/N threads (from --trace-thread)\n");
         of.puts("VM_TRACE_THREADS = ");
         of.puts(cvtToStr(v3Global.opt.trueTraceThreads()));
@@ -277,7 +281,6 @@ public:
         of.putsHeader();
     }
 
-public:
     explicit EmitMk() {
         emitClassMake();
         emitOverallMake();
@@ -359,10 +362,7 @@ class EmitMkHierVerilation {
             of.puts(v3Global.opt.prefix()
                     + ".mk: $(VM_HIER_INPUT_FILES) $(VM_HIER_VERILOG_LIBS) ");
             of.puts(V3Os::filenameNonDir(argsFile) + " ");
-            for (V3HierBlockPlan::const_iterator it = m_planp->begin(); it != m_planp->end();
-                 ++it) {
-                of.puts(it->second->hierWrapper(true) + " ");
-            }
+            for (const auto& itr : *m_planp) of.puts(itr.second->hierWrapper(true) + " ");
             of.puts("\n");
             emitLaunchVerilator(of, argsFile);
         }
