@@ -80,6 +80,7 @@
 #include "V3Error.h"
 #include "V3File.h"
 #include "V3HierBlock.h"
+#include "V3Os.h"
 #include "V3String.h"
 #include "V3Stats.h"
 
@@ -88,22 +89,26 @@ static string V3HierCommandArgsFileName(const string& prefix, bool forCMake) {
            + (forCMake ? "_hierCMakeArgs.f" : "_hierMkArgs.f");
 }
 
-static void V3HierWriteCommonInputs(std::ostream* of, bool forCMake) {
+static void V3HierWriteCommonInputs(const V3HierBlock* hblockp, std::ostream* of, bool forCMake) {
+    string topModuleFile;
+    if (hblockp) topModuleFile = hblockp->vFileIfNecessary();
     if (!forCMake) {
+        if (!topModuleFile.empty()) *of << topModuleFile << "\n";
         const V3StringList& vFiles = v3Global.opt.vFiles();
         for (const string& i : vFiles) *of << i << "\n";
     }
     const V3StringSet& libraryFiles = v3Global.opt.libraryFiles();
-    for (const string& i : libraryFiles) *of << "-v " << i << "\n";
+    for (const string& i : libraryFiles) {
+        if (V3Os::filenameRealPath(i) != topModuleFile) *of << "-v " << i << "\n";
+    }
 }
 
 //######################################################################
 
 V3HierBlock::StrGParams V3HierBlock::stringifyParams(const GParams& gparams, bool forGOption) {
     StrGParams strParams;
-    for (V3HierBlock::GParams::const_iterator gparamIt = gparams.begin();
-         gparamIt != gparams.end(); ++gparamIt) {
-        if (const AstConst* constp = VN_CAST((*gparamIt)->valuep(), Const)) {
+    for (const auto& gparam : gparams) {
+        if (const AstConst* constp = VN_CAST(gparam->valuep(), Const)) {
             string s;
             // Only constant parameter needs to be set to -G because already checked in
             // V3Param.cpp. See also ParamVisitor::checkSupportedParam() in the file.
@@ -125,7 +130,7 @@ V3HierBlock::StrGParams V3HierBlock::stringifyParams(const GParams& gparams, boo
                 s = constp->num().ascii(true, true);
                 s = VString::quoteAny(s, '\'', '\\');
             }
-            strParams.push_back(std::make_pair((*gparamIt)->name(), s));
+            strParams.push_back(std::make_pair(gparam->name(), s));
         }
     }
     return strParams;
@@ -133,9 +138,8 @@ V3HierBlock::StrGParams V3HierBlock::stringifyParams(const GParams& gparams, boo
 
 V3HierBlock::~V3HierBlock() {
     UASSERT(m_children.empty(), "at least one module must be a leaf");
-    for (HierBlockSet::const_iterator child = m_children.begin(); child != m_children.end();
-         ++child) {
-        const bool deleted = (*child)->m_children.erase(this);
+    for (const auto& hierblockp : m_children) {
+        const bool deleted = hierblockp->m_children.erase(this);
         UASSERT_OBJ(deleted, m_modp, " is not registered");
     }
 }
@@ -194,25 +198,33 @@ string V3HierBlock::hierGenerated(bool withDir) const {
     return hierWrapper(withDir) + ' ' + hierMk(withDir);
 }
 
+string V3HierBlock::vFileIfNecessary() const {
+    const string filename = V3Os::filenameRealPath(m_modp->fileline()->filename());
+    for (const string& v : v3Global.opt.vFiles()) {
+        // Already listed in vFiles, so no need to add the file.
+        if (filename == V3Os::filenameRealPath(v)) return "";
+    }
+    return filename;
+}
+
 void V3HierBlock::writeCommandArgsFile(bool forCMake) const {
     std::unique_ptr<std::ofstream> of(V3File::new_ofstream(commandArgsFileName(forCMake)));
     *of << "--cc\n";
 
     if (!forCMake) {
-        for (V3HierBlock::HierBlockSet::const_iterator child = m_children.begin();
-             child != m_children.end(); ++child) {
-            *of << v3Global.opt.makeDir() << "/" << (*child)->hierWrapper(true) << "\n";
+        for (const auto& hierblockp : m_children) {
+            *of << v3Global.opt.makeDir() << "/" << hierblockp->hierWrapper(true) << "\n";
         }
+        *of << "-Mdir " << v3Global.opt.makeDir() << "/" << hierPrefix() << " \n";
     }
-    *of << "-Mdir " << v3Global.opt.makeDir() << "/" << hierPrefix() << " \n";
-    V3HierWriteCommonInputs(of.get(), forCMake);
+    V3HierWriteCommonInputs(this, of.get(), forCMake);
     const V3StringList& commandOpts = commandArgs(false);
     for (const string& opt : commandOpts) *of << opt << "\n";
     *of << hierBlockArgs().front() << "\n";
-    for (HierBlockSet::const_iterator child = m_children.begin(); child != m_children.end();
-         ++child) {
-        *of << (*child)->hierBlockArgs().front() << "\n";
-    }
+    for (const auto& hierblockp : m_children) *of << hierblockp->hierBlockArgs().front() << "\n";
+    // Hierarchical blocks should not use multi-threading,
+    // but needs to be thread safe when top is multi-threaded.
+    if (v3Global.opt.threads() > 0) { *of << "--threads 1\n"; }
     *of << v3Global.opt.allArgsStringForHierBlock(false) << "\n";
 }
 
@@ -394,7 +406,7 @@ void V3HierBlockPlan::writeCommandArgsFiles(bool forCMake) const {
             *of << it->second->hierWrapper(true) << "\n";
         }
     }
-    V3HierWriteCommonInputs(of.get(), forCMake);
+    V3HierWriteCommonInputs(nullptr, of.get(), forCMake);
     if (!forCMake) {
         const V3StringSet& cppFiles = v3Global.opt.cppFiles();
         for (const string& i : cppFiles) *of << i << "\n";
@@ -411,10 +423,13 @@ void V3HierBlockPlan::writeCommandArgsFiles(bool forCMake) const {
         *of << "--protect-lib " << v3Global.opt.protectLib() << "\n";
         *of << "--protect-key " << v3Global.opt.protectKeyDefaulted() << "\n";
     }
+    if (v3Global.opt.threads() > 0) {
+        *of << "--threads " << cvtToStr(v3Global.opt.threads()) << "\n";
+    }
     *of << (v3Global.opt.systemC() ? "--sc" : "--cc") << "\n";
     *of << v3Global.opt.allArgsStringForHierBlock(true) << "\n";
 }
 
-string V3HierBlockPlan::topCommandArgsFileName(bool forCMake) const {
+string V3HierBlockPlan::topCommandArgsFileName(bool forCMake) {
     return V3HierCommandArgsFileName(v3Global.opt.prefix(), forCMake);
 }
