@@ -76,17 +76,17 @@ private:
             if (nodep->modVarp()->isInoutish()) {
                 nodep->v3fatalSrc("Unsupported: Verilator is a 2-state simulator");
             } else if (nodep->modVarp()->isWritable()) {
-                AstNode* rhsp
-                    = new AstVarXRef(exprp->fileline(), nodep->modVarp(), m_cellp->name(), false);
+                AstNode* rhsp = new AstVarXRef(exprp->fileline(), nodep->modVarp(),
+                                               m_cellp->name(), VAccess::READ);
                 AstAssignW* assp = new AstAssignW(exprp->fileline(), exprp, rhsp);
                 m_cellp->addNextHere(assp);
             } else if (nodep->modVarp()->isNonOutput()) {
                 // Don't bother moving constants now,
                 // we'll be pushing the const down to the cell soon enough.
-                AstNode* assp = new AstAssignW(
-                    exprp->fileline(),
-                    new AstVarXRef(exprp->fileline(), nodep->modVarp(), m_cellp->name(), true),
-                    exprp);
+                AstNode* assp = new AstAssignW(exprp->fileline(),
+                                               new AstVarXRef(exprp->fileline(), nodep->modVarp(),
+                                                              m_cellp->name(), VAccess::WRITE),
+                                               exprp);
                 m_cellp->addNextHere(assp);
                 if (debug() >= 9) assp->dumpTree(cout, "     _new: ");
             } else if (nodep->modVarp()->isIfaceRef()
@@ -96,8 +96,8 @@ private:
                                     IfaceRefDType))) {
                 // Create an AstAssignVarScope for Vars to Cells so we can
                 // link with their scope later
-                AstNode* lhsp
-                    = new AstVarXRef(exprp->fileline(), nodep->modVarp(), m_cellp->name(), false);
+                AstNode* lhsp = new AstVarXRef(exprp->fileline(), nodep->modVarp(),
+                                               m_cellp->name(), VAccess::READ);
                 const AstVarRef* refp = VN_CAST(exprp, VarRef);
                 const AstVarXRef* xrefp = VN_CAST(exprp, VarXRef);
                 UASSERT_OBJ(refp || xrefp, exprp,
@@ -141,7 +141,7 @@ class InstDeModVarVisitor : public AstNVisitor {
     // Expand all module variables, and save names for later reference
 private:
     // STATE
-    typedef std::map<string, AstVar*> VarNameMap;
+    typedef std::map<const string, AstVar*> VarNameMap;
     VarNameMap m_modVarNameMap;  // Per module, name of cloned variables
 
     VL_DEBUG_FUNC;  // Declare debug()
@@ -172,13 +172,11 @@ public:
         }
     }
     void dump() {
-        for (VarNameMap::iterator it = m_modVarNameMap.begin(); it != m_modVarNameMap.end();
-             ++it) {
-            cout << "-namemap: " << it->first << " -> " << it->second << endl;
+        for (const auto& itr : m_modVarNameMap) {
+            cout << "-namemap: " << itr.first << " -> " << itr.second << endl;
         }
     }
 
-public:
     // CONSTRUCTORS
     explicit InstDeModVarVisitor() {}
     void main(AstNodeModule* nodep) {
@@ -195,8 +193,8 @@ class InstDeVisitor : public AstNVisitor {
     // Find all cells with arrays, and convert to non-arrayed
 private:
     // STATE
-    AstRange* m_cellRangep
-        = nullptr;  // Range for arrayed instantiations, nullptr for normal instantiations
+    // Range for arrayed instantiations, nullptr for normal instantiations
+    AstRange* m_cellRangep = nullptr;
     int m_instSelNum = 0;  // Current instantiation count 0..N-1
     InstDeModVarVisitor m_deModVars;  // State of variables for current cell module
 
@@ -278,8 +276,7 @@ private:
                         = VN_CAST(arrdtype->subDTypep(), IfaceRefDType);
                     origIfaceRefp->cellp(nullptr);
                     AstVar* varNewp = ifaceVarp->cloneTree(false);
-                    AstIfaceRefDType* ifaceRefp
-                        = VN_CAST(arrdtype->subDTypep(), IfaceRefDType)->cloneTree(false);
+                    AstIfaceRefDType* ifaceRefp = origIfaceRefp->cloneTree(false);
                     arrdtype->addNextHere(ifaceRefp);
                     ifaceRefp->cellp(newp);
                     ifaceRefp->cellName(newp->name());
@@ -378,9 +375,13 @@ private:
                     return;
                 }
                 string index = AstNode::encodeNumber(constp->toSInt());
+                if (VN_IS(arrselp->lhsp(), SliceSel))
+                    arrselp->lhsp()->v3error("Unsupported: interface slices");
                 AstVarRef* varrefp = VN_CAST(arrselp->lhsp(), VarRef);
-                AstVarXRef* newp = new AstVarXRef(
-                    nodep->fileline(), varrefp->name() + "__BRA__" + index + "__KET__", "", true);
+                UASSERT_OBJ(varrefp, arrselp, "No interface varref under array");
+                AstVarXRef* newp = new AstVarXRef(nodep->fileline(),
+                                                  varrefp->name() + "__BRA__" + index + "__KET__",
+                                                  "", VAccess::WRITE);
                 newp->dtypep(nodep->modVarp()->dtypep());
                 newp->packagep(varrefp->packagep());
                 arrselp->addNextHere(newp);
@@ -438,7 +439,8 @@ private:
                 }
                 if (!varrefp) { newp->exprp()->v3error("Unexpected connection to arrayed port"); }
                 string newname = varrefp->name() + "__BRA__" + cvtToStr(i + offset) + "__KET__";
-                AstVarXRef* newVarXRefp = new AstVarXRef(nodep->fileline(), newname, "", true);
+                AstVarXRef* newVarXRefp
+                    = new AstVarXRef(nodep->fileline(), newname, "", VAccess::WRITE);
                 newVarXRefp->varp(newp->modVarp());
                 newp->exprp()->unlinkFrBack()->deleteTree();
                 newp->exprp(newVarXRefp);
@@ -553,18 +555,19 @@ public:
                                     " direct one-to-one connection (without any expression)");
             } else if (pinVarp->isWritable()) {
                 // See also V3Inst
-                AstNode* rhsp = new AstVarRef(pinp->fileline(), newvarp, false);
+                AstNode* rhsp = new AstVarRef(pinp->fileline(), newvarp, VAccess::READ);
                 UINFO(5, "pinRecon width " << pinVarp->width() << " >? " << rhsp->width() << " >? "
                                            << pinexprp->width() << endl);
                 rhsp = extendOrSel(pinp->fileline(), rhsp, pinVarp);
-                pinp->exprp(new AstVarRef(newvarp->fileline(), newvarp, true));
+                pinp->exprp(new AstVarRef(newvarp->fileline(), newvarp, VAccess::WRITE));
                 AstNode* rhsSelp = extendOrSel(pinp->fileline(), rhsp, pinexprp);
                 assignp = new AstAssignW(pinp->fileline(), pinexprp, rhsSelp);
             } else {
                 // V3 width should have range/extended to make the widths correct
                 assignp = new AstAssignW(pinp->fileline(),
-                                         new AstVarRef(pinp->fileline(), newvarp, true), pinexprp);
-                pinp->exprp(new AstVarRef(pinexprp->fileline(), newvarp, false));
+                                         new AstVarRef(pinp->fileline(), newvarp, VAccess::WRITE),
+                                         pinexprp);
+                pinp->exprp(new AstVarRef(pinexprp->fileline(), newvarp, VAccess::READ));
             }
             if (assignp) cellp->addNextHere(assignp);
             // if (debug()) { pinp->dumpTree(cout, "-  out:"); }
