@@ -44,7 +44,7 @@ private:
     AstUser2InUse m_inuser2;
 
     // TYPES
-    typedef std::map<std::pair<void*, string>, AstTypedef*> ImplTypedefMap;
+    typedef std::map<const std::pair<void*, string>, AstTypedef*> ImplTypedefMap;
     typedef std::set<FileLine*> FileLineSet;
 
     // STATE
@@ -57,6 +57,7 @@ private:
     AstNodeModule* m_modp = nullptr;  // Current module
     AstNodeFTask* m_ftaskp = nullptr;  // Current task
     AstNodeDType* m_dtypep = nullptr;  // Current data type
+    VLifetime m_lifetime = VLifetime::STATIC;  // Propagating lifetime
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -104,13 +105,20 @@ private:
 
     // VISITs
     virtual void visit(AstNodeFTask* nodep) override {
-        V3Config::applyFTask(m_modp, nodep);
-
         if (!nodep->user1SetOnce()) {  // Process only once.
+            V3Config::applyFTask(m_modp, nodep);
             cleanFileline(nodep);
-            m_ftaskp = nodep;
-            iterateChildren(nodep);
-            m_ftaskp = nullptr;
+            VL_RESTORER(m_ftaskp);
+            VL_RESTORER(m_lifetime);
+            {
+                m_ftaskp = nodep;
+                m_lifetime = nodep->lifetime();
+                if (m_lifetime.isNone()) {
+                    // Automatic always until we support static
+                    m_lifetime = VLifetime::AUTOMATIC;
+                }
+                iterateChildren(nodep);
+            }
         }
     }
     virtual void visit(AstNodeFTaskRef* nodep) override {
@@ -172,6 +180,13 @@ private:
 
     virtual void visit(AstVar* nodep) override {
         cleanFileline(nodep);
+        if (nodep->lifetime().isNone()) {
+            if (m_ftaskp) {
+                nodep->lifetime(VLifetime::AUTOMATIC);
+            } else {
+                nodep->lifetime(m_lifetime);
+            }
+        }
         if (nodep->isParam() && !nodep->valuep()
             && nodep->fileline()->language() < V3LangCode::L1800_2009) {
             nodep->v3error("Parameter requires default value, or use IEEE 1800-2009 or later.");
@@ -223,27 +238,24 @@ private:
             FileLine* fl = nodep->valuep()->fileline();
             if (nodep->isParam() || (m_ftaskp && nodep->isNonOutput())) {
                 // 1. Parameters and function inputs: It's a default to use if not overridden
-            } else if (VN_IS(m_modp, Class)) {
-                // 2. Class member init become initials (as might call functions)
-                // later move into class constructor
-                nodep->addNextHere(
-                    new AstInitial(fl, new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
-                                                     nodep->valuep()->unlinkFrBack())));
-            } else if (!m_ftaskp && nodep->isNonOutput()) {
+            } else if (!m_ftaskp && !VN_IS(m_modp, Class) && nodep->isNonOutput()) {
                 nodep->v3warn(E_UNSUPPORTED, "Unsupported: Default value on module input: "
                                                  << nodep->prettyNameQ());
                 nodep->valuep()->unlinkFrBack()->deleteTree();
-            }  // 3. Under modules, it's an initial value to be loaded at time 0 via an AstInitial
+            }  // 2. Under modules/class, it's an initial value to be loaded at time 0 via an
+               // AstInitial
             else if (m_valueModp) {
                 // Making an AstAssign (vs AstAssignW) to a wire is an error, suppress it
                 FileLine* newfl = new FileLine(fl);
                 newfl->warnOff(V3ErrorCode::PROCASSWIRE, true);
-                nodep->addNextHere(new AstInitial(
-                    newfl, new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), true),
-                                         nodep->valuep()->unlinkFrBack())));
+                auto* assp
+                    = new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), VAccess::WRITE),
+                                    nodep->valuep()->unlinkFrBack());
+                nodep->addNextHere(new AstInitial(newfl, assp));
             }  // 4. Under blocks, it's an initial value to be under an assign
             else {
-                nodep->addNextHere(new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
+                nodep->addNextHere(new AstAssign(fl,
+                                                 new AstVarRef(fl, nodep->name(), VAccess::WRITE),
                                                  nodep->valuep()->unlinkFrBack()));
             }
         }
@@ -333,7 +345,8 @@ private:
             // lvalue is true, because we know we have a verilator public_flat_rw
             // but someday we may be more general
             bool lvalue = m_varp->isSigUserRWPublic();
-            nodep->addStmtp(new AstVarRef(nodep->fileline(), m_varp, lvalue));
+            nodep->addStmtp(
+                new AstVarRef(nodep->fileline(), m_varp, lvalue ? VAccess::WRITE : VAccess::READ));
         }
     }
 
@@ -445,7 +458,8 @@ private:
                                            new AstConst(fl, dimension));
             AstNode* stmtsp = varp;
             // Assign left-dimension into the loop var:
-            stmtsp->addNext(new AstAssign(fl, new AstVarRef(fl, varp->name(), true), leftp));
+            stmtsp->addNext(
+                new AstAssign(fl, new AstVarRef(fl, varp->name(), VAccess::WRITE), leftp));
             // This will turn into a constant bool for static arrays
             AstNode* notemptyp = new AstGt(fl, sizep, new AstConst(fl, 0));
             // This will turn into a bool constant, indicating whether
@@ -454,14 +468,15 @@ private:
             AstNode* comparep = new AstCond(
                 fl, countupp->cloneTree(true),
                 // Left increments up to right
-                new AstLte(fl, new AstVarRef(fl, varp->name(), false), rightp->cloneTree(true)),
+                new AstLte(fl, new AstVarRef(fl, varp->name(), VAccess::READ),
+                           rightp->cloneTree(true)),
                 // Left decrements down to right
-                new AstGte(fl, new AstVarRef(fl, varp->name(), false), rightp));
+                new AstGte(fl, new AstVarRef(fl, varp->name(), VAccess::READ), rightp));
             // This will reduce to comparep for static arrays
             AstNode* condp = new AstAnd(fl, notemptyp, comparep);
             AstNode* incp = new AstAssign(
-                fl, new AstVarRef(fl, varp->name(), true),
-                new AstAdd(fl, new AstVarRef(fl, varp->name(), false),
+                fl, new AstVarRef(fl, varp->name(), VAccess::WRITE),
+                new AstAdd(fl, new AstVarRef(fl, varp->name(), VAccess::READ),
                            new AstCond(fl, countupp, new AstConst(fl, 1), new AstConst(fl, -1))));
             stmtsp->addNext(new AstWhile(fl, condp, newp, incp));
             newp = new AstBegin(nodep->fileline(), "", stmtsp, false, true);
@@ -477,12 +492,17 @@ private:
         V3Config::applyModule(nodep);
 
         VL_RESTORER(m_modp);
+        VL_RESTORER(m_lifetime);
         {
             // Module: Create sim table for entire module and iterate
             cleanFileline(nodep);
             //
             m_modp = nodep;
             m_valueModp = nodep;
+            m_lifetime = nodep->lifetime();
+            if (m_lifetime.isNone()) {
+                m_lifetime = VN_IS(nodep, Class) ? VLifetime::AUTOMATIC : VLifetime::STATIC;
+            }
             iterateChildren(nodep);
         }
         m_valueModp = nodep;
