@@ -51,7 +51,6 @@ private:
     AstClass* m_classp = nullptr;  // Class we're inside
     AstNodeFTask* m_ftaskp = nullptr;  // Function or task we're inside
     AstNodeCoverOrAssert* m_assertp = nullptr;  // Current assertion
-    VLifetime m_lifetime = VLifetime::STATIC;  // Propagating lifetime
     int m_senitemCvtNum = 0;  // Temporary signal counter
 
     // METHODS
@@ -66,23 +65,17 @@ private:
         UINFO(8, "MODULE " << nodep << endl);
         if (nodep->dead()) return;
         VL_RESTORER(m_modp);
-        VL_RESTORER(m_lifetime);
         VL_RESTORER(m_senitemCvtNum);
         {
             m_modp = nodep;
             m_senitemCvtNum = 0;
-            m_lifetime = nodep->lifetime();
-            if (m_lifetime.isNone()) m_lifetime = VLifetime::STATIC;
             iterateChildren(nodep);
         }
     }
     virtual void visit(AstClass* nodep) override {
         VL_RESTORER(m_classp);
-        VL_RESTORER(m_lifetime);
         {
             m_classp = nodep;
-            m_lifetime = nodep->lifetime();
-            if (m_lifetime.isNone()) m_lifetime = VLifetime::AUTOMATIC;
             iterateChildren(nodep);
         }
     }
@@ -106,13 +99,6 @@ private:
         if (m_classp && nodep->isParam())
             nodep->v3warn(E_UNSUPPORTED, "Unsupported: class parameter");
         if (m_ftaskp) nodep->funcLocal(true);
-        if (nodep->lifetime().isNone()) {
-            if (nodep->isFuncLocal() && nodep->isIO()) {
-                nodep->lifetime(VLifetime::AUTOMATIC);
-            } else {
-                nodep->lifetime(m_lifetime);
-            }
-        }
         if (nodep->isSigModPublic()) {
             nodep->sigModPublic(false);  // We're done with this attribute
             m_modp->modPublic(true);  // Avoid flattening if signals are exposed
@@ -136,15 +122,11 @@ private:
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
             return;
         }
-        VLifetime origLifetime = m_lifetime;
         {
-            m_lifetime = nodep->lifetime();
-            if (m_lifetime.isNone()) m_lifetime = VLifetime::AUTOMATIC;
             m_ftaskp = nodep;
             iterateChildren(nodep);
         }
         m_ftaskp = nullptr;
-        m_lifetime = origLifetime;
         if (nodep->dpiExport()) { nodep->scopeNamep(new AstScopeName(nodep->fileline())); }
     }
     virtual void visit(AstNodeFTaskRef* nodep) override {
@@ -183,33 +165,34 @@ private:
                 }
                 addwherep->addNext(newvarp);
 
-                sensp->replaceWith(new AstVarRef(sensp->fileline(), newvarp, false));
+                sensp->replaceWith(new AstVarRef(sensp->fileline(), newvarp, VAccess::READ));
                 AstAssignW* assignp = new AstAssignW(
-                    sensp->fileline(), new AstVarRef(sensp->fileline(), newvarp, true), sensp);
+                    sensp->fileline(), new AstVarRef(sensp->fileline(), newvarp, VAccess::WRITE),
+                    sensp);
                 addwherep->addNext(assignp);
             }
         } else {  // Old V1995 sensitivity list; we'll probably mostly ignore
-            bool did = 1;
+            bool did = true;
             while (did) {
-                did = 0;
+                did = false;
                 if (AstNodeSel* selp = VN_CAST(nodep->sensp(), NodeSel)) {
                     AstNode* fromp = selp->fromp()->unlinkFrBack();
                     selp->replaceWith(fromp);
                     VL_DO_DANGLING(selp->deleteTree(), selp);
-                    did = 1;
+                    did = true;
                 }
                 // NodeSel doesn't include AstSel....
                 if (AstSel* selp = VN_CAST(nodep->sensp(), Sel)) {
                     AstNode* fromp = selp->fromp()->unlinkFrBack();
                     selp->replaceWith(fromp);
                     VL_DO_DANGLING(selp->deleteTree(), selp);
-                    did = 1;
+                    did = true;
                 }
                 if (AstNodePreSel* selp = VN_CAST(nodep->sensp(), NodePreSel)) {
                     AstNode* fromp = selp->lhsp()->unlinkFrBack();
                     selp->replaceWith(fromp);
                     VL_DO_DANGLING(selp->deleteTree(), selp);
-                    did = 1;
+                    did = true;
                 }
             }
         }
@@ -376,7 +359,7 @@ private:
                         if (!inpercent && c == '%') {
                             inpercent = true;
                         } else if (inpercent) {
-                            inpercent = 0;
+                            inpercent = false;
                             switch (c) {
                             case '0':  // FALLTHRU
                             case '1':  // FALLTHRU
@@ -409,7 +392,7 @@ private:
         return newFormat;
     }
 
-    void expectDescriptor(AstNode* nodep, AstNodeVarRef* filep) {
+    static void expectDescriptor(AstNode* nodep, AstNodeVarRef* filep) {
         if (!filep) {
             nodep->v3warn(E_UNSUPPORTED,
                           "Unsupported: $fopen/$fclose/$f* descriptor must be a simple variable");
@@ -490,7 +473,8 @@ private:
                         varoutp = varp;
                         // Tie off
                         m_modp->addStmtp(new AstAssignW(
-                            varp->fileline(), new AstVarRef(varp->fileline(), varp, true),
+                            varp->fileline(),
+                            new AstVarRef(varp->fileline(), varp, VAccess::WRITE),
                             new AstConst(varp->fileline(), AstConst::LogicFalse())));
                     } else {
                         varp->v3error("Only inputs and outputs are allowed in udp modules");
@@ -518,6 +502,16 @@ private:
         iterateChildren(nodep);
     }
 
+    virtual void visit(AstIfaceRefDType* nodep) override {
+        // LinkDot checked modports, now remove references to them
+        // Keeping them later caused problems with InstDeArray,
+        // as it needed to make new modport arrays and such
+        nodep->modportp(nullptr);
+        iterateChildren(nodep);
+    }
+    // virtual void visit(AstModport* nodep) override { ... }
+    // We keep Modport's themselves around for XML dump purposes
+
     virtual void visit(AstNode* nodep) override { iterateChildren(nodep); }
 
 public:
