@@ -53,7 +53,7 @@
 class V3OptionsImp {
 public:
     // TYPES
-    typedef std::map<string, std::set<string>> DirMap;  // Directory listing
+    typedef std::map<const string, std::set<string>> DirMap;  // Directory listing
 
     // STATE
     std::list<string> m_allArgs;  // List of every argument encountered
@@ -61,7 +61,7 @@ public:
     std::set<string> m_incDirUserSet;  // Include directories (for removing duplicates)
     std::list<string> m_incDirFallbacks;  // Include directories (ordered)
     std::set<string> m_incDirFallbackSet;  // Include directories (for removing duplicates)
-    std::map<string, V3LangCode> m_langExts;  // Language extension map
+    std::map<const string, V3LangCode> m_langExts;  // Language extension map
     std::list<string> m_libExtVs;  // Library extensions (ordered)
     std::set<string> m_libExtVSet;  // Library extensions (for removing duplicates)
     DirMap m_dirMap;  // Directory listing
@@ -346,10 +346,7 @@ void V3Options::checkParameters() {
     if (!m_parameters.empty()) {
         std::stringstream msg;
         msg << "Parameters from the command line were not found in the design:";
-        for (std::map<string, string>::iterator it = m_parameters.begin();
-             it != m_parameters.end(); ++it) {
-            msg << " " << it->first;
-        }
+        for (const auto& i : m_parameters) msg << " " << i.first;
         v3error(msg.str());
     }
 }
@@ -395,8 +392,7 @@ string V3Options::allArgsString() const {
 // Delete some options for Verilation of the hierarchical blocks.
 string V3Options::allArgsStringForHierBlock(bool forTop) const {
     std::set<string> vFiles;
-    for (V3StringList::const_iterator it = m_vFiles.begin(); it != m_vFiles.end(); ++it)
-        vFiles.insert(*it);
+    for (const auto& vFile : m_vFiles) vFiles.insert(vFile);
     string out;
     for (std::list<string>::const_iterator it = m_impp->m_allArgs.begin();
          it != m_impp->m_allArgs.end(); ++it) {
@@ -431,15 +427,6 @@ string V3Options::allArgsStringForHierBlock(bool forTop) const {
 //######################################################################
 // File searching
 
-bool V3Options::fileStatDir(const string& filename) {
-    // NOLINTNEXTLINE(cppcoreguidelines-pro-type-member-init)
-    struct stat sstat;  // Stat information
-    int err = stat(filename.c_str(), &sstat);
-    if (err != 0) return false;
-    if (!S_ISDIR(sstat.st_mode)) return false;
-    return true;
-}
-
 bool V3Options::fileStatNormal(const string& filename) {
     // NOLINTNEXTLINE(cppcoreguidelines-pro-type-member-init)
     struct stat sstat;  // Stat information
@@ -510,10 +497,10 @@ string V3Options::filePathCheckOneDir(const string& modname, const string& dirna
 // 0: Keep the option including its argument
 // 1: Delete the option which has no argument
 // 2: Delete the option and its argument
-int V3Options::stripOptionsForChildRun(const string& opt, bool forTop) const {
+int V3Options::stripOptionsForChildRun(const string& opt, bool forTop) {
     if (opt == "Mdir" || opt == "clk" || opt == "f" || opt == "j" || opt == "l2-name"
         || opt == "mod-prefix" || opt == "prefix" || opt == "protect-lib" || opt == "protect-key"
-        || opt == "top-module" || opt == "v") {
+        || opt == "threads" || opt == "top-module" || opt == "v") {
         return 2;
     }
     if (opt == "build" || (!forTop && (opt == "cc" || opt == "exe" || opt == "sc"))
@@ -651,9 +638,9 @@ string V3Options::getenvSYSTEMC_ARCH() {
         struct utsname uts;
         uname(&uts);
         string sysname = VString::downcase(uts.sysname);  // aka  'uname -s'
-        if (VString::wildmatch(sysname.c_str(), "*solaris*")) {
+        if (VL_UNCOVERABLE(VString::wildmatch(sysname.c_str(), "*solaris*"))) {
             var = "gccsparcOS5";
-        } else if (VString::wildmatch(sysname.c_str(), "*cygwin*")) {
+        } else if (VL_UNCOVERABLE(VString::wildmatch(sysname.c_str(), "*cygwin*"))) {
             var = "cygwin";
         } else {
             var = "linux";
@@ -1013,6 +1000,8 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                 m_debugCheck = flag;
             } else if (onoff(sw, "-debug-collision", flag /*ref*/)) {  // Undocumented
                 m_debugCollision = flag;
+            } else if (onoff(sw, "-debug-emitv", flag /*ref*/)) {  // Undocumented
+                m_debugEmitV = flag;
             } else if (onoff(sw, "-debug-exit-parse", flag /*ref*/)) {  // Undocumented
                 m_debugExitParse = flag;
             } else if (onoff(sw, "-debug-exit-uvm", flag /*ref*/)) {  // Undocumented
@@ -1594,6 +1583,7 @@ void V3Options::parseOptsFile(FileLine* fl, const string& filename, bool rel) {
         string oline;
         // cppcheck-suppress StlMissingComparison
         char lastch = ' ';
+        bool space_begin = true;  // At beginning or leading spaces only
         for (string::const_iterator pos = line.begin(); pos != line.end(); lastch = *pos++) {
             if (inCmt) {
                 if (*pos == '*' && *(pos + 1) == '/') {
@@ -1603,11 +1593,15 @@ void V3Options::parseOptsFile(FileLine* fl, const string& filename, bool rel) {
             } else if (*pos == '/' && *(pos + 1) == '/'
                        && (pos == line.begin() || isspace(lastch))) {  // But allow /file//path
                 break;  // Ignore to EOL
+            } else if (*pos == '#' && space_begin) {  // Only # at [spaced] begin of line
+                break;  // Ignore to EOL
             } else if (*pos == '/' && *(pos + 1) == '*') {
                 inCmt = true;
+                space_begin = false;
                 // cppcheck-suppress StlMissingComparison
                 ++pos;
             } else {
+                if (!isspace(*pos)) space_begin = false;
                 oline += *pos;
             }
         }
