@@ -201,7 +201,7 @@ typedef std::set<string> V3StringSet;
 class V3HierarchicalBlockOption {
 public:
     // key:parameter name, value:value (as string)
-    typedef std::map<string, string> ParamStrMap;
+    typedef std::map<const string, string> ParamStrMap;
 
 private:
     string m_origName;  // module name
@@ -218,7 +218,7 @@ public:
     const ParamStrMap params() const { return m_parameters; }
 };
 
-typedef std::map<string, V3HierarchicalBlockOption> V3HierBlockOptSet;
+typedef std::map<const string, V3HierarchicalBlockOption> V3HierBlockOptSet;
 
 //######################################################################
 // V3Options - Command line options
@@ -227,7 +227,7 @@ class V3Options {
 public:
 private:
     // TYPES
-    typedef std::map<string, int> DebugSrcMap;
+    typedef std::map<const string, int> DebugSrcMap;
 
     // MEMBERS (general options)
     V3OptionsImp* m_impp;  // Slow hidden options
@@ -245,8 +245,8 @@ private:
     V3StringList m_forceIncs;   // argument: -FI
     DebugSrcMap m_debugSrcs;    // argument: --debugi-<srcfile>=<level>
     DebugSrcMap m_dumpTrees;    // argument: --dump-treei-<srcfile>=<level>
-    std::map<string,string> m_parameters;  // Parameters
-    std::map<string, V3HierarchicalBlockOption> m_hierBlocks;  // main switch: --hierarchical-block
+    std::map<const string, string> m_parameters;  // Parameters
+    std::map<const string, V3HierarchicalBlockOption> m_hierBlocks;  // main switch: --hierarchical-block
 
     bool m_preprocOnly = false;     // main switch: -E
     bool m_makePhony = false;       // main switch: -MP
@@ -265,6 +265,7 @@ private:
     bool m_coverageUser = false;    // main switch: --coverage-func
     bool m_debugCheck = false;      // main switch: --debug-check
     bool m_debugCollision = false;  // main switch: --debug-collision
+    bool m_debugEmitV = false;      // main switch: --debug-emitv
     bool m_debugExitParse = false;  // main switch: --debug-exit-parse
     bool m_debugExitUvm = false;    // main switch: --debug-exit-uvm
     bool m_debugLeak = true;        // main switch: --debug-leak
@@ -409,13 +410,13 @@ private:
     void optimize(int level);
     void showVersion(bool verbose);
     void coverage(bool flag) { m_coverageLine = m_coverageToggle = m_coverageUser = flag; }
-    bool onoff(const char* sw, const char* arg, bool& flag);
-    bool onoffb(const char* sw, const char* arg, VOptionBool& flagr);
-    bool suffixed(const string& sw, const char* arg);
-    string parseFileArg(const string& optdir, const string& relfilename);
+    static bool onoff(const char* sw, const char* arg, bool& flag);
+    static bool onoffb(const char* sw, const char* arg, VOptionBool& flagr);
+    static bool suffixed(const string& sw, const char* arg);
+    static string parseFileArg(const string& optdir, const string& relfilename);
     bool parseLangExt(const char* swp, const char* langswp, const V3LangCode& lc);
     string filePathCheckOneDir(const string& modname, const string& dirname);
-    int stripOptionsForChildRun(const string& opt, bool forTop) const;
+    static int stripOptionsForChildRun(const string& opt, bool forTop);
 
     // CONSTRUCTORS
     VL_UNCOPYABLE(V3Options);
@@ -469,6 +470,7 @@ public:
     bool coverageUser() const { return m_coverageUser; }
     bool debugCheck() const { return m_debugCheck; }
     bool debugCollision() const { return m_debugCollision; }
+    bool debugEmitV() const { return m_debugEmitV; }
     bool debugExitParse() const { return m_debugExitParse; }
     bool debugExitUvm() const { return m_debugExitUvm; }
     bool debugLeak() const { return m_debugLeak; }
@@ -669,7 +671,6 @@ public:
                     const string& errmsg);
     void filePathLookedMsg(FileLine* fl, const string& modname);
     V3LangCode fileLanguage(const string& filename);
-    static bool fileStatDir(const string& filename);
     static bool fileStatNormal(const string& filename);
     static void fileNfsFlush(const string& filename);
 
