@@ -68,8 +68,8 @@
 class ParameterizedHierBlocks {
     typedef std::multimap<string, const V3HierarchicalBlockOption*> HierBlockOptsByOrigName;
     typedef HierBlockOptsByOrigName::const_iterator HierMapIt;
-    typedef std::map<string, AstNodeModule*> HierBlockModMap;
-    typedef std::map<string, AstConst*> ParamConstMap;
+    typedef std::map<const string, AstNodeModule*> HierBlockModMap;
+    typedef std::map<const string, AstConst*> ParamConstMap;
     typedef std::map<const V3HierarchicalBlockOption*, ParamConstMap> ParamsMap;
 
     // MEMBERS
@@ -119,10 +119,11 @@ class ParameterizedHierBlocks {
 
 public:
     ParameterizedHierBlocks(const V3HierBlockOptSet& hierOpts, AstNetlist* nodep) {
-        for (V3HierBlockOptSet::const_iterator it = hierOpts.begin(); it != hierOpts.end(); ++it) {
-            m_hierBlockOptsByOrigName.insert(std::make_pair(it->second.origName(), &it->second));
-            const V3HierarchicalBlockOption::ParamStrMap& params = it->second.params();
-            ParamConstMap& consts = m_params[&it->second];
+        for (const auto& hierOpt : hierOpts) {
+            m_hierBlockOptsByOrigName.insert(
+                std::make_pair(hierOpt.second.origName(), &hierOpt.second));
+            const V3HierarchicalBlockOption::ParamStrMap& params = hierOpt.second.params();
+            ParamConstMap& consts = m_params[&hierOpt.second];
             for (V3HierarchicalBlockOption::ParamStrMap::const_iterator pIt = params.begin();
                  pIt != params.end(); ++pIt) {
                 AstConst* constp = AstConst::parseParamLiteral(
@@ -141,10 +142,7 @@ public:
     }
     ~ParameterizedHierBlocks() {
         for (ParamsMap::const_iterator it = m_params.begin(); it != m_params.end(); ++it) {
-            for (ParamConstMap::const_iterator pIt = it->second.begin(); pIt != it->second.end();
-                 ++pIt) {
-                delete pIt->second;
-            }
+            for (const auto& pItr : it->second) { delete pItr.second; }
         }
     }
     AstNodeModule* findByParams(const string& origName, AstPin* firstPinp,
@@ -218,17 +216,17 @@ private:
     typedef std::deque<std::pair<AstIfaceRefDType*, AstIfaceRefDType*>> IfaceRefRefs;
 
     // STATE
-    typedef std::map<AstNode*, AstNode*> CloneMap;
+    typedef std::map<const AstNode*, AstNode*> CloneMap;
     struct ModInfo {
         AstNodeModule* m_modp;  // Module with specified name
         CloneMap m_cloneMap;  // Map of old-varp -> new cloned varp
         explicit ModInfo(AstNodeModule* modp)
             : m_modp{modp} {}
     };
-    typedef std::map<string, ModInfo> ModNameMap;
+    typedef std::map<const string, ModInfo> ModNameMap;
     ModNameMap m_modNameMap;  // Hash of created module flavors by name
 
-    typedef std::map<string, string> LongMap;
+    typedef std::map<const string, string> LongMap;
     LongMap m_longMap;  // Hash of very long names to unique identity number
     int m_longId = 0;
 
@@ -237,7 +235,7 @@ private:
     V3StringSet m_allModuleNames;
 
     typedef std::pair<int, string> ValueMapValue;
-    typedef std::map<V3Hash, ValueMapValue> ValueMap;
+    typedef std::map<const V3Hash, ValueMapValue> ValueMap;
     ValueMap m_valueMap;  // Hash of node hash to (param value, name)
     int m_nextValue = 1;  // Next value to use in m_valueMap
 
@@ -370,7 +368,7 @@ private:
         }
     }
     void relinkPinsByName(AstPin* startpinp, AstNodeModule* modp) {
-        std::map<string, AstVar*> nameToPin;
+        std::map<const string, AstVar*> nameToPin;
         for (AstNode* stmtp = modp->stmtsp(); stmtp; stmtp = stmtp->nextp()) {
             if (AstVar* varp = VN_CAST(stmtp, Var)) {
                 if (varp->isIO() || varp->isGParam() || varp->isIfaceRef()) {
@@ -535,7 +533,7 @@ private:
                         nodep->addNext(new AstInitial(
                             nodep->fileline(),
                             new AstAssign(nodep->fileline(),
-                                          new AstVarRef(nodep->fileline(), nodep, true),
+                                          new AstVarRef(nodep->fileline(), nodep, VAccess::WRITE),
                                           nodep->valuep()->cloneTree(true))));
                         if (m_ftaskp) {
                             // We put the initial in wrong place under a function.  We
@@ -892,10 +890,13 @@ void ParamVisitor::visitCell(AstCell* nodep, const string& hierName) {
 
                 AstIfaceRefDType* pinIrefp = nullptr;
                 AstNode* exprp = pinp->exprp();
-                if (exprp && VN_IS(exprp, VarRef) && VN_CAST(exprp, VarRef)->varp()
-                    && VN_CAST(exprp, VarRef)->varp()->subDTypep()
-                    && VN_IS(VN_CAST(exprp, VarRef)->varp()->subDTypep(), IfaceRefDType)) {
-                    pinIrefp = VN_CAST(VN_CAST(exprp, VarRef)->varp()->subDTypep(), IfaceRefDType);
+                AstVar* varp
+                    = (exprp && VN_IS(exprp, VarRef)) ? VN_CAST(exprp, VarRef)->varp() : nullptr;
+                if (varp && varp->subDTypep() && VN_IS(varp->subDTypep(), IfaceRefDType)) {
+                    pinIrefp = VN_CAST(varp->subDTypep(), IfaceRefDType);
+                } else if (varp && varp->subDTypep() && arraySubDTypep(varp->subDTypep())
+                           && VN_CAST(arraySubDTypep(varp->subDTypep()), IfaceRefDType)) {
+                    pinIrefp = VN_CAST(arraySubDTypep(varp->subDTypep()), IfaceRefDType);
                 } else if (exprp && exprp->op1p() && VN_IS(exprp->op1p(), VarRef)
                            && VN_CAST(exprp->op1p(), VarRef)->varp()
                            && VN_CAST(exprp->op1p(), VarRef)->varp()->subDTypep()
@@ -906,13 +907,6 @@ void ParamVisitor::visitCell(AstCell* nodep, const string& hierName) {
                     pinIrefp = VN_CAST(
                         arraySubDTypep(VN_CAST(exprp->op1p(), VarRef)->varp()->subDTypep()),
                         IfaceRefDType);
-                } else if (exprp && VN_IS(exprp, VarRef) && VN_CAST(exprp, VarRef)->varp()
-                           && VN_CAST(exprp, VarRef)->varp()->subDTypep()
-                           && arraySubDTypep(VN_CAST(exprp, VarRef)->varp()->subDTypep())
-                           && VN_CAST(arraySubDTypep(VN_CAST(exprp, VarRef)->varp()->subDTypep()),
-                                      IfaceRefDType)) {
-                    pinIrefp = VN_CAST(arraySubDTypep(VN_CAST(exprp, VarRef)->varp()->subDTypep()),
-                                       IfaceRefDType);
                 }
 
                 UINFO(9, "     portIfaceRef " << portIrefp << endl);
