@@ -58,7 +58,7 @@ private:
     }
     virtual void visit(AstVarRef* nodep) override {
         // it's LHS var is used so need a deep temporary
-        if (nodep->lvalue()) {
+        if (nodep->access().isWriteOrRW()) {
             nodep->varp()->user4(true);
         } else {
             if (nodep->varp()->user4()) {
@@ -94,7 +94,7 @@ private:
 
     // STATE
     AstNodeModule* m_modp = nullptr;  // Current module
-    AstCFunc* m_funcp = nullptr;  // Current block
+    AstCFunc* m_cfuncp = nullptr;  // Current block
     AstNode* m_stmtp = nullptr;  // Current statement
     AstWhile* m_inWhilep = nullptr;  // Inside while loop, special statement additions
     AstTraceInc* m_inTracep = nullptr;  // Inside while loop, special statement additions
@@ -141,7 +141,7 @@ private:
         string newvarname = (string("__Vtemp") + cvtToStr(m_modp->varNumGetInc()));
         AstVar* varp
             = new AstVar(nodep->fileline(), AstVarType::STMTTEMP, newvarname, nodep->dtypep());
-        m_funcp->addInitsp(varp);
+        m_cfuncp->addInitsp(varp);
         return varp;
     }
 
@@ -173,11 +173,11 @@ private:
         AstVar* varp = getBlockTemp(nodep);
         if (noSubst) varp->noSubst(true);  // Do not remove varrefs to this in V3Const
         // Replace node tree with reference to var
-        AstVarRef* newp = new AstVarRef(nodep->fileline(), varp, false);
+        AstVarRef* newp = new AstVarRef(nodep->fileline(), varp, VAccess::READ);
         linker.relink(newp);
         // Put assignment before the referencing statement
-        AstAssign* assp = new AstAssign(nodep->fileline(),
-                                        new AstVarRef(nodep->fileline(), varp, true), nodep);
+        AstAssign* assp = new AstAssign(
+            nodep->fileline(), new AstVarRef(nodep->fileline(), varp, VAccess::WRITE), nodep);
         insertBeforeStmt(assp);
         if (debug() > 8) assp->dumpTree(cout, "deepou:");
         nodep->user1(true);  // Don't add another assignment
@@ -189,18 +189,20 @@ private:
         VL_RESTORER(m_modp);
         {
             m_modp = nodep;
-            m_funcp = nullptr;
+            m_cfuncp = nullptr;
             iterateChildren(nodep);
         }
     }
     virtual void visit(AstCFunc* nodep) override {
-        m_funcp = nodep;
-        iterateChildren(nodep);
-        m_funcp = nullptr;
+        VL_RESTORER(m_cfuncp);
+        {
+            m_cfuncp = nodep;
+            iterateChildren(nodep);
+        }
     }
     void startStatement(AstNode* nodep) {
         m_assignLhs = false;
-        if (m_funcp) m_stmtp = nodep;
+        if (m_cfuncp) m_stmtp = nodep;
     }
     virtual void visit(AstWhile* nodep) override {
         UINFO(4, "  WHILE  " << nodep << endl);
