@@ -306,7 +306,7 @@ private:
         iterate(nodep->rhsp());
         AstVarRef* varrefp = VN_CAST(nodep->lhsp(), VarRef);
         AstConst* constp = VN_CAST(nodep->rhsp(), Const);
-        if (varrefp && isSubstVar(varrefp->varp()) && !varrefp->lvalue() && constp) {
+        if (varrefp && isSubstVar(varrefp->varp()) && varrefp->access().isReadOnly() && constp) {
             // Nicely formed lvalues handled in NodeAssign
             // Other lvalues handled as unknown mess in AstVarRef
             int word = constp->toUInt();
@@ -329,14 +329,14 @@ private:
     }
     virtual void visit(AstVarRef* nodep) override {
         // Any variable
-        if (nodep->lvalue()) {
+        if (nodep->access().isWriteOrRW()) {
             m_assignStep++;
             nodep->varp()->user2(m_assignStep);
             UINFO(9, " ASSIGNstep u2=" << nodep->varp()->user2() << " " << nodep << endl);
         }
         if (isSubstVar(nodep->varp())) {
             SubstVarEntry* entryp = getEntryp(nodep);
-            if (nodep->lvalue()) {
+            if (nodep->access().isWriteOrRW()) {
                 UINFO(8, " ASSIGNcpx " << nodep << endl);
                 entryp->assignComplex();
             } else if (AstNode* substp = entryp->substWhole(nodep)) {
@@ -365,11 +365,7 @@ private:
 
 public:
     // CONSTRUCTORS
-    explicit SubstVisitor(AstNode* nodep) {
-        AstNode::user1ClearTree();  // user1p() used on entire tree
-        AstNode::user2ClearTree();  // user2p() used on entire tree
-        iterate(nodep);
-    }
+    explicit SubstVisitor(AstNode* nodep) { iterate(nodep); }
     virtual ~SubstVisitor() override {
         V3Stats::addStat("Optimizations, Substituted temps", m_statSubsts);
         for (SubstVarEntry* ip : m_entryps) {
