@@ -154,10 +154,11 @@ public:
         // Called by TableSimulateVisitor on each unique varref encountered
         UINFO(9, "   SimVARREF " << nodep << endl);
         AstVarScope* vscp = nodep->varScopep();
-        if (nodep->lvalue()) {
+        if (nodep->access().isWriteOrRW()) {
             m_outWidth += nodep->varp()->dtypeSkipRefp()->widthTotalBytes();
             m_outVarps.push_back(vscp);
-        } else {
+        }
+        if (nodep->access().isReadOrRW()) {
             // We'll make the table with a separate natural alignment for each
             // output var, so always have char, 16 or 32 bit widths, so use widthTotalBytes
             m_inWidth += nodep->varp()->width();  // Space for var
@@ -199,10 +200,7 @@ private:
 
         // Collapse duplicate tables
         chgVscp = findDuplicateTable(chgVscp);
-        for (std::deque<AstVarScope*>::iterator it = m_tableVarps.begin();
-             it != m_tableVarps.end(); ++it) {
-            *it = findDuplicateTable(*it);
-        }
+        for (auto& vscp : m_tableVarps) vscp = findDuplicateTable(vscp);
 
         createOutputAssigns(nodep, stmtsp, indexVscp, chgVscp);
 
@@ -222,7 +220,7 @@ private:
 
     void createTableVars(AstNode* nodep) {
         // Create table for each output
-        typedef std::map<string, int> NameCounts;
+        typedef std::map<const string, int> NameCounts;
         NameCounts namecounts;
         for (const AstVarScope* outvscp : m_outVarps) {
             AstVar* outvarp = outvscp->varp();
@@ -255,7 +253,7 @@ private:
         // First var in inVars becomes the LSB of the concat
         AstNode* concatp = nullptr;
         for (AstVarScope* invscp : m_inVarps) {
-            AstVarRef* refp = new AstVarRef(nodep->fileline(), invscp, false);
+            AstVarRef* refp = new AstVarRef(nodep->fileline(), invscp, VAccess::READ);
             if (concatp) {
                 concatp = new AstConcat(nodep->fileline(), refp, concatp);
             } else {
@@ -263,8 +261,9 @@ private:
             }
         }
 
-        AstNode* stmtsp = new AstAssign(
-            nodep->fileline(), new AstVarRef(nodep->fileline(), indexVscp, true), concatp);
+        AstNode* stmtsp
+            = new AstAssign(nodep->fileline(),
+                            new AstVarRef(nodep->fileline(), indexVscp, VAccess::WRITE), concatp);
         return stmtsp;
     }
 
@@ -372,10 +371,11 @@ private:
         // Set each output from array ref into our table
         int outnum = 0;
         for (AstVarScope* outvscp : m_outVarps) {
-            AstNode* alhsp = new AstVarRef(nodep->fileline(), outvscp, true);
+            AstNode* alhsp = new AstVarRef(nodep->fileline(), outvscp, VAccess::WRITE);
             AstNode* arhsp = new AstArraySel(
-                nodep->fileline(), new AstVarRef(nodep->fileline(), m_tableVarps[outnum], false),
-                new AstVarRef(nodep->fileline(), indexVscp, false));
+                nodep->fileline(),
+                new AstVarRef(nodep->fileline(), m_tableVarps[outnum], VAccess::READ),
+                new AstVarRef(nodep->fileline(), indexVscp, VAccess::READ));
             AstNode* outasnp
                 = (m_assignDly
                        ? static_cast<AstNode*>(new AstAssignDly(nodep->fileline(), alhsp, arhsp))
@@ -389,9 +389,10 @@ private:
                 outsetp = new AstIf(
                     nodep->fileline(),
                     new AstAnd(nodep->fileline(),
-                               new AstArraySel(nodep->fileline(),
-                                               new AstVarRef(nodep->fileline(), chgVscp, false),
-                                               new AstVarRef(nodep->fileline(), indexVscp, false)),
+                               new AstArraySel(
+                                   nodep->fileline(),
+                                   new AstVarRef(nodep->fileline(), chgVscp, VAccess::READ),
+                                   new AstVarRef(nodep->fileline(), indexVscp, VAccess::READ)),
                                new AstConst(nodep->fileline(), outputChgMask)),
                     outsetp, nullptr);
             }
