@@ -104,7 +104,7 @@ private:
 
     // TYPES
     typedef std::map<std::pair<AstScope*, AstVar*>, AstVarScope*> VarToScopeMap;
-    typedef std::map<AstNodeFTask*, AstClass*> FuncToClassMap;
+    typedef std::map<const AstNodeFTask*, AstClass*> FuncToClassMap;
     typedef std::vector<AstInitial*> Initials;
     // MEMBERS
     VarToScopeMap m_varToScopeMap;  // Map for Var -> VarScope mappings
@@ -341,7 +341,7 @@ private:
         IM_AFTER,  // Pointing at last inserted stmt, insert after
         IM_WHILE_PRECOND  // Pointing to for loop, add to body end
     };
-    typedef std::map<string, std::pair<AstNodeFTask*, string>> DpiNames;
+    typedef std::map<const string, std::pair<AstNodeFTask*, string>> DpiNames;
 
     // STATE
     TaskStateVisitor* m_statep;  // Common state between visitors
@@ -402,9 +402,9 @@ private:
         // Create input variables
         AstNode::user2ClearTree();
         V3TaskConnects tconnects = V3Task::taskConnects(refp, beginp);
-        for (V3TaskConnects::iterator it = tconnects.begin(); it != tconnects.end(); ++it) {
-            AstVar* portp = it->first;
-            AstArg* argp = it->second;
+        for (const auto& itr : tconnects) {
+            AstVar* portp = itr.first;
+            AstArg* argp = itr.second;
             AstNode* pinp = argp->exprp();
             portp->unlinkFrBack();
             pushDeletep(portp);  // Remove it from the clone (not original)
@@ -448,9 +448,9 @@ private:
                     AstVarScope* tempvscp
                         = createVarScope(portp, namePrefix + "__" + portp->shortName());
                     portp->user2p(tempvscp);
-                    AstAssign* assp
-                        = new AstAssign(pinp->fileline(), pinp,
-                                        new AstVarRef(tempvscp->fileline(), tempvscp, false));
+                    AstAssign* assp = new AstAssign(
+                        pinp->fileline(), pinp,
+                        new AstVarRef(tempvscp->fileline(), tempvscp, VAccess::READ));
                     assp->fileline()->modifyWarnOff(V3ErrorCode::BLKSEQ,
                                                     true);  // Ok if in <= block
                     // Put assignment BEHIND of all other statements
@@ -461,7 +461,8 @@ private:
                         = createVarScope(portp, namePrefix + "__" + portp->shortName());
                     portp->user2p(inVscp);
                     AstAssign* assp = new AstAssign(
-                        pinp->fileline(), new AstVarRef(inVscp->fileline(), inVscp, true), pinp);
+                        pinp->fileline(),
+                        new AstVarRef(inVscp->fileline(), inVscp, VAccess::WRITE), pinp);
                     assp->fileline()->modifyWarnOff(V3ErrorCode::BLKSEQ,
                                                     true);  // Ok if in <= block
                     // Put assignment in FRONT of all other statements
@@ -535,9 +536,9 @@ private:
 
         // Convert complicated outputs to temp signals
         V3TaskConnects tconnects = V3Task::taskConnects(refp, refp->taskp()->stmtsp());
-        for (V3TaskConnects::iterator it = tconnects.begin(); it != tconnects.end(); ++it) {
-            AstVar* portp = it->first;
-            AstNode* pinp = it->second->exprp();
+        for (const auto& itr : tconnects) {
+            AstVar* portp = itr.first;
+            AstNode* pinp = itr.second->exprp();
             if (!pinp) {
                 // Too few arguments in function call
             } else {
@@ -571,10 +572,10 @@ private:
                     AstVarScope* newvscp
                         = createVarScope(portp, namePrefix + "__" + portp->shortName());
                     portp->user2p(newvscp);
-                    pinp->replaceWith(new AstVarRef(newvscp->fileline(), newvscp, true));
-                    AstAssign* assp
-                        = new AstAssign(pinp->fileline(), pinp,
-                                        new AstVarRef(newvscp->fileline(), newvscp, false));
+                    pinp->replaceWith(new AstVarRef(newvscp->fileline(), newvscp, VAccess::WRITE));
+                    AstAssign* assp = new AstAssign(
+                        pinp->fileline(), pinp,
+                        new AstVarRef(newvscp->fileline(), newvscp, VAccess::READ));
                     assp->fileline()->modifyWarnOff(V3ErrorCode::BLKSEQ,
                                                     true);  // Ok if in <= block
                     // Put assignment BEHIND of all other statements
@@ -608,7 +609,7 @@ private:
             ccallp->addArgsp(exprp);
         }
 
-        if (outvscp) ccallp->addArgsp(new AstVarRef(refp->fileline(), outvscp, true));
+        if (outvscp) ccallp->addArgsp(new AstVarRef(refp->fileline(), outvscp, VAccess::WRITE));
 
         if (debug() >= 9) beginp->dumpTreeAndNext(cout, "-nitask: ");
         return beginp;
@@ -661,7 +662,7 @@ private:
         bool useSetWSvlv = V3Task::dpiToInternalFrStmt(portp, frName, frstmt);
         if (useSetWSvlv) {
             AstNode* linesp = new AstText(portp->fileline(), frstmt);
-            linesp->addNext(new AstVarRef(portp->fileline(), portvscp, true));
+            linesp->addNext(new AstVarRef(portp->fileline(), portvscp, VAccess::WRITE));
             linesp->addNext(new AstText(portp->fileline(), "," + frName + ");"));
             return new AstCStmt(portp->fileline(), linesp);
         }
@@ -675,13 +676,14 @@ private:
             }
         }
         AstNode* newp = new AstAssign(
-            portp->fileline(), new AstVarRef(portp->fileline(), portvscp, true),
+            portp->fileline(), new AstVarRef(portp->fileline(), portvscp, VAccess::WRITE),
             new AstSel(portp->fileline(), new AstCMath(portp->fileline(), frstmt, cwidth, false),
                        0, portp->width()));
         return newp;
     }
 
     void makeDpiExportWrapper(AstNodeFTask* nodep, AstVar* rtnvarp) {
+        const char* const tmpSuffixp = V3Task::dpiTemporaryVarSuffix();
         AstCFunc* dpip = new AstCFunc(nodep->fileline(), nodep->cname(), m_scopep,
                                       (rtnvarp ? rtnvarp->dpiArgType(true, true) : ""));
         dpip->dontCombine(true);
@@ -736,12 +738,13 @@ private:
                         argnodesp = argnodesp->addNext(new AstText(portp->fileline(), args, true));
                         args = "";
                     }
-                    AstVarScope* outvscp = createFuncVar(dpip, portp->name() + "__Vcvt", portp);
+                    AstVarScope* outvscp = createFuncVar(dpip, portp->name() + tmpSuffixp, portp);
                     // No information exposure; is already visible in import/export func template
                     outvscp->varp()->protect(false);
                     portp->protect(false);
                     AstVarRef* refp
-                        = new AstVarRef(portp->fileline(), outvscp, portp->isWritable());
+                        = new AstVarRef(portp->fileline(), outvscp,
+                                        portp->isWritable() ? VAccess::WRITE : VAccess::READ);
                     argnodesp = argnodesp->addNextNull(refp);
 
                     if (portp->isNonOutput()) {
@@ -762,10 +765,11 @@ private:
                 argnodesp = argnodesp->addNext(new AstText(portp->fileline(), args, true));
                 args = "";
             }
-            AstVarScope* outvscp = createFuncVar(dpip, portp->name() + "__Vcvt", portp);
+            AstVarScope* outvscp = createFuncVar(dpip, portp->name() + tmpSuffixp, portp);
             // No information exposure; is already visible in import/export func template
             outvscp->varp()->protect(false);
-            AstVarRef* refp = new AstVarRef(portp->fileline(), outvscp, portp->isWritable());
+            AstVarRef* refp = new AstVarRef(portp->fileline(), outvscp,
+                                            portp->isWritable() ? VAccess::WRITE : VAccess::READ);
             argnodesp = argnodesp->addNextNull(refp);
         }
 
@@ -786,14 +790,14 @@ private:
         for (AstNode* stmtp = nodep->stmtsp(); stmtp; stmtp = stmtp->nextp()) {
             if (AstVar* portp = VN_CAST(stmtp, Var)) {
                 if (portp->isIO() && portp->isWritable() && !portp->isFuncReturn()) {
-                    dpip->addStmtsp(createAssignInternalToDpi(portp, true, "__Vcvt", ""));
+                    dpip->addStmtsp(createAssignInternalToDpi(portp, true, tmpSuffixp, ""));
                 }
             }
         }
 
         if (rtnvarp) {
             dpip->addStmtsp(createDpiTemp(rtnvarp, ""));
-            dpip->addStmtsp(createAssignInternalToDpi(rtnvarp, false, "__Vcvt", ""));
+            dpip->addStmtsp(createAssignInternalToDpi(rtnvarp, false, tmpSuffixp, ""));
             string stmt = "return " + rtnvarp->name();
             stmt += rtnvarp->basicp()->isDpiPrimitive() ? ";\n" : "[0];\n";
             dpip->addStmtsp(new AstCStmt(nodep->fileline(), stmt));
@@ -870,6 +874,7 @@ private:
     }
 
     void bodyDpiImportFunc(AstNodeFTask* nodep, AstVarScope* rtnvscp, AstCFunc* cfuncp) {
+        const char* const tmpSuffixp = V3Task::dpiTemporaryVarSuffix();
         // Convert input/inout arguments to DPI types
         string args;
         for (AstNode* stmtp = cfuncp->argsp(); stmtp; stmtp = stmtp->nextp()) {
@@ -911,12 +916,12 @@ private:
                             args += "&";
                         }
 
-                        args += portp->name() + "__Vcvt";
+                        args += portp->name() + tmpSuffixp;
 
-                        cfuncp->addStmtsp(createDpiTemp(portp, "__Vcvt"));
+                        cfuncp->addStmtsp(createDpiTemp(portp, tmpSuffixp));
                         if (portp->isNonOutput()) {
                             cfuncp->addStmtsp(
-                                createAssignInternalToDpi(portp, false, "", "__Vcvt"));
+                                createAssignInternalToDpi(portp, false, "", tmpSuffixp));
                         }
                     }
                 }
@@ -932,8 +937,8 @@ private:
         {  // Call the user function
             string stmt;
             if (rtnvscp) {  // isFunction will no longer work as we unlinked the return var
-                cfuncp->addStmtsp(createDpiTemp(rtnvscp->varp(), "__Vcvt"));
-                stmt = rtnvscp->varp()->name() + "__Vcvt";
+                cfuncp->addStmtsp(createDpiTemp(rtnvscp->varp(), tmpSuffixp));
+                stmt = rtnvscp->varp()->name() + tmpSuffixp;
                 stmt += rtnvscp->varp()->basicp()->isDpiPrimitive() ? " = " : "[0] = ";
             }
             stmt += nodep->cname() + "(" + args + ");\n";
@@ -949,7 +954,7 @@ private:
                     AstVarScope* portvscp = VN_CAST(
                         portp->user2p(), VarScope);  // Remembered when we created it earlier
                     cfuncp->addStmtsp(
-                        createAssignDpiToInternal(portvscp, portp->name() + "__Vcvt"));
+                        createAssignDpiToInternal(portvscp, portp->name() + tmpSuffixp));
                 }
             }
         }
@@ -1134,8 +1139,8 @@ private:
 
         // Return statement
         if (rtnvscp && nodep->taskPublic()) {
-            cfuncp->addFinalsp(new AstCReturn(rtnvscp->fileline(),
-                                              new AstVarRef(rtnvscp->fileline(), rtnvscp, false)));
+            cfuncp->addFinalsp(new AstCReturn(
+                rtnvscp->fileline(), new AstVarRef(rtnvscp->fileline(), rtnvscp, VAccess::READ)));
         }
         // Replace variable refs
         // Iteration requires a back, so put under temporary node
@@ -1245,7 +1250,7 @@ private:
             visitp = insertBeforeStmt(nodep, beginp);
         } else if (!nodep->isStatement()) {
             UASSERT_OBJ(nodep->taskp()->isFunction(), nodep, "func reference to non-function");
-            AstVarRef* outrefp = new AstVarRef(nodep->fileline(), outvscp, false);
+            AstVarRef* outrefp = new AstVarRef(nodep->fileline(), outvscp, VAccess::READ);
             nodep->replaceWith(outrefp);
             // Insert new statements
             visitp = insertBeforeStmt(nodep, beginp);
@@ -1371,7 +1376,6 @@ public:
     // CONSTRUCTORS
     TaskVisitor(AstNetlist* nodep, TaskStateVisitor* statep)
         : m_statep{statep} {
-        AstNode::user1ClearTree();
         iterate(nodep);
     }
     virtual ~TaskVisitor() override {}
@@ -1386,7 +1390,7 @@ V3TaskConnects V3Task::taskConnects(AstNodeFTaskRef* nodep, AstNode* taskStmtsp)
     // Missing pin/expr?  We return (pinvar, nullptr)
     // Extra   pin/expr?  We clean it up
 
-    typedef std::map<string, int> NameToIndex;
+    typedef std::map<const string, int> NameToIndex;
     NameToIndex nameToIndex;
     V3TaskConnects tconnects;
     UASSERT_OBJ(nodep->taskp(), nodep, "unlinked");
@@ -1575,6 +1579,11 @@ bool V3Task::dpiToInternalFrStmt(AstVar* portp, const string& frName, string& fr
     return false;
 }
 
+const char* V3Task::dpiTemporaryVarSuffix() {
+    static const char suffix[] = "__Vcvt";
+    return suffix;
+}
+
 void V3Task::taskAll(AstNetlist* nodep) {
     UINFO(2, __FUNCTION__ << ": " << endl);
     {
