@@ -169,7 +169,7 @@ private:
     // STATE
     AstNodeModule* m_topModp = nullptr;  // Module to add variables to
     AstScope* m_topScopep = nullptr;  // Scope to add variables to
-    AstCFunc* m_funcp = nullptr;  // C function adding to graph
+    AstCFunc* m_cfuncp = nullptr;  // C function adding to graph
     AstTraceDecl* m_tracep = nullptr;  // Trace function adding to graph
     AstVarScope* m_activityVscp = nullptr;  // Activity variable
     uint32_t m_activityNumber = 0;  // Count of fields in activity variable
@@ -419,13 +419,13 @@ private:
         graphSimplify(false);
     }
 
-    AstNode* selectActivity(FileLine* flp, uint32_t acode, bool lvalue) {
-        return new AstArraySel(flp, new AstVarRef(flp, m_activityVscp, lvalue), acode);
+    AstNode* selectActivity(FileLine* flp, uint32_t acode, const VAccess& access) {
+        return new AstArraySel(flp, new AstVarRef(flp, m_activityVscp, access), acode);
     }
 
     void addActivitySetter(AstNode* insertp, uint32_t code) {
         FileLine* const fl = insertp->fileline();
-        AstAssign* const setterp = new AstAssign(fl, selectActivity(fl, code, true),
+        AstAssign* const setterp = new AstAssign(fl, selectActivity(fl, code, VAccess::WRITE),
                                                  new AstConst(fl, AstConst::LogicTrue()));
         if (AstCCall* const callp = VN_CAST(insertp, CCall)) {
             callp->addNextHere(setterp);
@@ -638,7 +638,7 @@ private:
                         condp = new AstConst(flp, 1);  // Always true, will be folded later
                     } else {
                         for (const uint32_t actCode : actSet) {
-                            AstNode* const selp = selectActivity(flp, actCode, false);
+                            AstNode* const selp = selectActivity(flp, actCode, VAccess::READ);
                             condp = condp ? new AstOr(flp, condp, selp) : selp;
                         }
                     }
@@ -651,7 +651,7 @@ private:
 
                 // Add TraceInc node
                 AstTraceDecl* const declp = vtxp->nodep();
-                AstTraceInc* const incp = new AstTraceInc(declp->fileline(), declp, false);
+                AstTraceInc* const incp = new AstTraceInc(declp->fileline(), declp, VAccess::READ);
                 ifp->addIfsp(incp);
                 subStmts += EmitCBaseCounterVisitor(incp).count();
 
@@ -686,7 +686,7 @@ private:
 
         // Clear fine grained activity flags
         for (uint32_t i = 0; i < m_activityNumber; ++i) {
-            AstNode* const clrp = new AstAssign(fl, selectActivity(fl, i, true),
+            AstNode* const clrp = new AstAssign(fl, selectActivity(fl, i, VAccess::WRITE),
                                                 new AstConst(fl, AstConst::LogicFalse()));
             cleanupFuncp->addStmtsp(clrp);
         }
@@ -741,8 +741,8 @@ private:
 
         // Remove refs to traced values from TraceDecl nodes, these have now moved under
         // TraceInc
-        for (TraceVec::iterator it = traces.begin(); it != traces.end(); ++it) {
-            AstNode* const valuep = it->second->nodep()->valuep();
+        for (const auto& i : traces) {
+            AstNode* const valuep = i.second->nodep()->valuep();
             valuep->unlinkFrBack();
             valuep->deleteTree();
         }
@@ -826,9 +826,11 @@ private:
                 new V3GraphEdge(&m_graph, activityVtxp, funcVtxp, 1);
             }
         }
-        m_funcp = nodep;
-        iterateChildren(nodep);
-        m_funcp = nullptr;
+        VL_RESTORER(m_cfuncp);
+        {
+            m_cfuncp = nodep;
+            iterateChildren(nodep);
+        }
     }
     virtual void visit(AstTraceDecl* nodep) override {
         UINFO(8, "   TRACE " << nodep << endl);
@@ -836,7 +838,7 @@ private:
             V3GraphVertex* const vertexp = new TraceTraceVertex(&m_graph, nodep);
             nodep->user1p(vertexp);
 
-            UASSERT_OBJ(m_funcp, nodep, "Trace not under func");
+            UASSERT_OBJ(m_cfuncp, nodep, "Trace not under func");
             m_tracep = nodep;
             iterateChildren(nodep);
             m_tracep = nullptr;
@@ -845,7 +847,7 @@ private:
     virtual void visit(AstVarRef* nodep) override {
         if (m_tracep) {
             UASSERT_OBJ(nodep->varScopep(), nodep, "No var scope?");
-            UASSERT_OBJ(!nodep->lvalue(), nodep, "Lvalue in trace?  Should be const.");
+            UASSERT_OBJ(nodep->access().isReadOnly(), nodep, "Lvalue in trace?  Should be const.");
             V3GraphVertex* varVtxp = nodep->varScopep()->user1u().toGraphVertex();
             if (!varVtxp) {
                 varVtxp = new TraceVarVertex(&m_graph, nodep->varScopep());
@@ -857,9 +859,9 @@ private:
                 || nodep->varp()->isSigPublic()) {  // Or ones user can change
                 new V3GraphEdge(&m_graph, m_alwaysVtxp, traceVtxp, 1);
             }
-        } else if (m_funcp && m_finding && nodep->lvalue()) {
+        } else if (m_cfuncp && m_finding && nodep->access().isWriteOrRW()) {
             UASSERT_OBJ(nodep->varScopep(), nodep, "No var scope?");
-            V3GraphVertex* const funcVtxp = getCFuncVertexp(m_funcp);
+            V3GraphVertex* const funcVtxp = getCFuncVertexp(m_cfuncp);
             V3GraphVertex* const varVtxp = nodep->varScopep()->user1u().toGraphVertex();
             if (varVtxp) {  // else we're not tracing this signal
                 new V3GraphEdge(&m_graph, funcVtxp, varVtxp, 1);
