@@ -168,7 +168,7 @@ private:
             for (V3GraphEdge* edgep = vtxp->inBeginp(); edgep; edgep = edgep->inNextp()) {
                 TristateVertex* vvertexp = dynamic_cast<TristateVertex*>(edgep->fromp());
                 if (const AstVarRef* refp = VN_CAST(vvertexp->nodep(), VarRef)) {
-                    if (refp->lvalue()
+                    if (refp->access().isWriteOrRW()
                         // Doesn't hurt to not check if already set, but by doing so when we
                         // print out the debug messages, we'll see this node at level 0 instead.
                         && !vvertexp->isTristate()) {
@@ -276,12 +276,13 @@ class TristatePinVisitor : public TristateBaseVisitor {
     bool m_lvalue;  // Flip to be an LVALUE
     // VISITORS
     virtual void visit(AstVarRef* nodep) override {
-        if (m_lvalue && !nodep->lvalue()) {
+        UASSERT_OBJ(!nodep->access().isRW(), nodep, "Tristate unexpected on R/W access flip");
+        if (m_lvalue && !nodep->access().isWriteOrRW()) {
             UINFO(9, "  Flip-to-LValue " << nodep << endl);
-            nodep->lvalue(true);
-        } else if (!m_lvalue && nodep->lvalue()) {
+            nodep->access(VAccess::WRITE);
+        } else if (!m_lvalue && !nodep->access().isReadOnly()) {
             UINFO(9, "  Flip-to-RValue " << nodep << endl);
-            nodep->lvalue(false);
+            nodep->access(VAccess::READ);
             // Mark the ex-output as tristated
             UINFO(9, "  setTristate-subpin " << nodep->varp() << endl);
             m_tgraph.setTristate(nodep->varp());
@@ -479,8 +480,7 @@ class TristateVisitor : public TristateBaseVisitor {
         // or inouts without high-Z logic and put a 1'bz driver on them and add
         // them to the lhs map so they get expanded correctly.
         TristateGraph::VarVec vars = m_tgraph.tristateVars();
-        for (TristateGraph::VarVec::iterator ii = vars.begin(); ii != vars.end(); ++ii) {
-            AstVar* varp = (*ii);
+        for (auto varp : vars) {
             if (m_tgraph.isTristate(varp)) {
                 const auto it = m_lhsmap.find(varp);
                 if (it == m_lhsmap.end()) {
@@ -489,7 +489,7 @@ class TristateVisitor : public TristateBaseVisitor {
                     UINFO(8, "  Adding driver to var " << varp << endl);
                     AstConst* constp = new AstConst(varp->fileline(), AstConst::WidthedValue(),
                                                     varp->width(), 0);
-                    AstVarRef* varrefp = new AstVarRef(varp->fileline(), varp, true);
+                    AstVarRef* varrefp = new AstVarRef(varp->fileline(), varp, VAccess::WRITE);
                     AstNode* newp = new AstAssignW(varp->fileline(), varrefp, constp);
                     UINFO(9, "       newoev " << newp << endl);
                     varrefp->user1p(new AstConst(varp->fileline(), AstConst::WidthedValue(),
@@ -556,8 +556,7 @@ class TristateVisitor : public TristateBaseVisitor {
             AstNode* undrivenp = nullptr;
 
             // loop through the lhs drivers to build the driver resolution logic
-            for (RefVec::iterator ii = refsp->begin(); ii != refsp->end(); ++ii) {
-                AstVarRef* refp = (*ii);
+            for (auto refp : *refsp) {
                 int w = lhsp->width();
 
                 // create the new lhs driver for this var
@@ -577,24 +576,25 @@ class TristateVisitor : public TristateBaseVisitor {
                 nodep->addStmtp(newenp);
 
                 AstNode* enassp = new AstAssignW(
-                    refp->fileline(), new AstVarRef(refp->fileline(), newenp, true), getEnp(refp));
+                    refp->fileline(), new AstVarRef(refp->fileline(), newenp, VAccess::WRITE),
+                    getEnp(refp));
                 UINFO(9, "       newass " << enassp << endl);
                 nodep->addStmtp(enassp);
 
                 // now append this driver to the driver logic.
-                AstNode* ref1p = new AstVarRef(refp->fileline(), newlhsp, false);
-                AstNode* ref2p = new AstVarRef(refp->fileline(), newenp, false);
+                AstNode* ref1p = new AstVarRef(refp->fileline(), newlhsp, VAccess::READ);
+                AstNode* ref2p = new AstVarRef(refp->fileline(), newenp, VAccess::READ);
                 AstNode* andp = new AstAnd(refp->fileline(), ref1p, ref2p);
 
                 // or this to the others
                 orp = (!orp) ? andp : new AstOr(refp->fileline(), orp, andp);
 
                 if (envarp) {
-                    AstNode* ref3p = new AstVarRef(refp->fileline(), newenp, false);
+                    AstNode* ref3p = new AstVarRef(refp->fileline(), newenp, VAccess::READ);
                     enp = (!enp) ? ref3p : new AstOr(ref3p->fileline(), enp, ref3p);
                 }
-                AstNode* tmp = new AstNot(newenp->fileline(),
-                                          new AstVarRef(newenp->fileline(), newenp, false));
+                AstNode* tmp = new AstNot(
+                    newenp->fileline(), new AstVarRef(newenp->fileline(), newenp, VAccess::READ));
                 undrivenp = ((!undrivenp) ? tmp : new AstAnd(refp->fileline(), tmp, undrivenp));
             }
             if (!undrivenp) {  // No drivers on the bus
@@ -621,11 +621,12 @@ class TristateVisitor : public TristateBaseVisitor {
             }
             if (envarp) {
                 nodep->addStmtp(new AstAssignW(
-                    enp->fileline(), new AstVarRef(envarp->fileline(), envarp, true), enp));
+                    enp->fileline(), new AstVarRef(envarp->fileline(), envarp, VAccess::WRITE),
+                    enp));
             }
             // __out (child) or <in> (parent) = drive-value expression
-            AstNode* assp = new AstAssignW(lhsp->fileline(),
-                                           new AstVarRef(lhsp->fileline(), lhsp, true), orp);
+            AstNode* assp = new AstAssignW(
+                lhsp->fileline(), new AstVarRef(lhsp->fileline(), lhsp, VAccess::WRITE), orp);
             assp->user2(U2_BOTH);  // Don't process further; already resolved
             if (debug() >= 9) assp->dumpTree(cout, "-lhsp-eqn: ");
             nodep->addStmtp(assp);
@@ -647,7 +648,7 @@ class TristateVisitor : public TristateBaseVisitor {
                 // due to the pinReconnectSimple call in visit AstPin.
                 // We can ignore the output override by making a temporary
                 AstVar* varp = getCreateUnconnVarp(nodep, nodep->dtypep());
-                AstNode* newp = new AstVarRef(nodep->fileline(), varp, true);
+                AstNode* newp = new AstVarRef(nodep->fileline(), varp, VAccess::WRITE);
                 UINFO(9, " const->" << newp << endl);
                 nodep->replaceWith(newp);
                 VL_DO_DANGLING(pushDeletep(nodep), nodep);
@@ -945,10 +946,12 @@ class TristateVisitor : public TristateBaseVisitor {
                                        ->num();  // visit(AstConst) already split into en/ones
                 const V3Number& oneIfEnOne = constp->num();
                 AstVar* envarp = getCreateEnVarp(varrefp->varp());
-                AstNode* newp = new AstLogAnd(
-                    fl, new AstEq(fl, new AstConst(fl, oneIfEn), new AstVarRef(fl, envarp, false)),
-                    // Keep the caseeq if there are X's present
-                    new AstEqCase(fl, new AstConst(fl, oneIfEnOne), varrefp));
+                AstNode* newp
+                    = new AstLogAnd(fl,
+                                    new AstEq(fl, new AstConst(fl, oneIfEn),
+                                              new AstVarRef(fl, envarp, VAccess::READ)),
+                                    // Keep the caseeq if there are X's present
+                                    new AstEqCase(fl, new AstConst(fl, oneIfEnOne), varrefp));
                 if (neq) newp = new AstLogNot(fl, newp);
                 UINFO(9, "       newceq " << newp << endl);
                 if (debug() >= 9) nodep->dumpTree(cout, "-caseeq-old: ");
@@ -992,7 +995,7 @@ class TristateVisitor : public TristateBaseVisitor {
             nodep->v3warn(E_UNSUPPORTED, "Unsupported pullup/down (weak driver) construct.");
         } else {
             if (m_graphing) {
-                varrefp->lvalue(true);
+                varrefp->access(VAccess::WRITE);
                 m_logicp = nodep;
                 m_tgraph.setTristate(nodep);
                 associateLogic(nodep, varrefp->varp());
@@ -1004,7 +1007,7 @@ class TristateVisitor : public TristateBaseVisitor {
                 // current limitation of this implementation is that a pullup/down
                 // gets applied to all bits of a bus and a bus cannot have drivers
                 // in opposite directions on individual pins.
-                varrefp->lvalue(true);
+                varrefp->access(VAccess::WRITE);
                 m_tgraph.didProcess(nodep);
                 m_tgraph.didProcess(varrefp->varp());
                 setPullDirection(varrefp->varp(), nodep);
@@ -1082,7 +1085,9 @@ class TristateVisitor : public TristateBaseVisitor {
                 AstVar* ucVarp = getCreateUnconnVarp(nodep, nodep->modVarp()->dtypep());
                 nodep->exprp(new AstVarRef(nodep->fileline(), ucVarp,
                                            // We converted, so use declaration output state
-                                           nodep->modVarp()->declDirection().isWritable()));
+                                           nodep->modVarp()->declDirection().isWritable()
+                                               ? VAccess::WRITE
+                                               : VAccess::READ));
                 m_tgraph.setTristate(ucVarp);
                 // We don't need a driver on the wire; the lack of one will default to tristate
             } else if (inDeclProcessing) {  // Not an input that was a converted tristate
@@ -1103,15 +1108,16 @@ class TristateVisitor : public TristateBaseVisitor {
                                             nodep->name() + "__en" + cvtToStr(m_unique++),
                                             VFlagBitPacked(), enModVarp->width());
                 UINFO(9, "       newenv " << enVarp << endl);
-                AstPin* enpinp = new AstPin(nodep->fileline(), nodep->pinNum(),
-                                            enModVarp->name(),  // should be {var}"__en"
-                                            new AstVarRef(nodep->fileline(), enVarp, true));
+                AstPin* enpinp
+                    = new AstPin(nodep->fileline(), nodep->pinNum(),
+                                 enModVarp->name(),  // should be {var}"__en"
+                                 new AstVarRef(nodep->fileline(), enVarp, VAccess::WRITE));
                 enpinp->modVarp(enModVarp);
                 UINFO(9, "       newpin " << enpinp << endl);
                 enpinp->user2(U2_BOTH);  // don't iterate the pin later
                 nodep->addNextHere(enpinp);
                 m_modp->addStmtp(enVarp);
-                enrefp = new AstVarRef(nodep->fileline(), enVarp, false);
+                enrefp = new AstVarRef(nodep->fileline(), enVarp, VAccess::READ);
                 UINFO(9, "       newvrf " << enrefp << endl);
                 if (debug() >= 9) enpinp->dumpTree(cout, "-pin-ena: ");
             }
@@ -1215,22 +1221,20 @@ class TristateVisitor : public TristateBaseVisitor {
     virtual void visit(AstVarRef* nodep) override {
         UINFO(9, dbgState() << nodep << endl);
         if (m_graphing) {
-            if (nodep->lvalue()) {
-                associateLogic(nodep, nodep->varp());
-            } else {
-                associateLogic(nodep->varp(), nodep);
-            }
+            if (nodep->access().isWriteOrRW()) associateLogic(nodep, nodep->varp());
+            if (nodep->access().isReadOrRW()) associateLogic(nodep->varp(), nodep);
         } else {
             if (nodep->user2() & U2_NONGRAPH) return;  // Processed
             nodep->user2(U2_NONGRAPH);
             // Detect all var lhs drivers and adds them to the
             // VarMap so that after the walk through the module we can expand
             // any tristate logic on the driver.
-            if (nodep->lvalue() && m_tgraph.isTristate(nodep->varp())) {
+            if (nodep->access().isWriteOrRW() && m_tgraph.isTristate(nodep->varp())) {
                 UINFO(9, "     Ref-to-lvalue " << nodep << endl);
+                UASSERT_OBJ(!nodep->access().isRW(), nodep, "Tristate unexpected on R/W access");
                 m_tgraph.didProcess(nodep);
                 mapInsertLhsVarRef(nodep);
-            } else if (!nodep->lvalue()
+            } else if (nodep->access().isReadOnly()
                        // Not already processed, nor varref from visit(AstPin) creation
                        && !nodep->user1p()
                        // Reference to another tristate variable
@@ -1240,7 +1244,7 @@ class TristateVisitor : public TristateBaseVisitor {
                 // Then propagate the enable from the original variable
                 UINFO(9, "     Ref-to-tri " << nodep << endl);
                 AstVar* enVarp = getCreateEnVarp(nodep->varp());
-                nodep->user1p(new AstVarRef(nodep->fileline(), enVarp, false));
+                nodep->user1p(new AstVarRef(nodep->fileline(), enVarp, VAccess::READ));
             }
             if (m_alhs) {}  // NOP; user1() already passed down from assignment
         }
@@ -1254,9 +1258,9 @@ class TristateVisitor : public TristateBaseVisitor {
             if (nodep->user2() & U2_GRAPHING) return;  // Already processed
             nodep->user2(U2_GRAPHING);
             if (nodep->isPulldown() || nodep->isPullup()) {
-                AstNode* newp
-                    = new AstPull(nodep->fileline(), new AstVarRef(nodep->fileline(), nodep, true),
-                                  nodep->isPullup());
+                AstNode* newp = new AstPull(
+                    nodep->fileline(), new AstVarRef(nodep->fileline(), nodep, VAccess::WRITE),
+                    nodep->isPullup());
                 UINFO(9, "       newpul " << newp << endl);
                 nodep->addNextHere(newp);
                 // We'll iterate on the new AstPull later
