@@ -318,7 +318,7 @@ private:
             for (int usr = 1; usr < (m_alwaysCombp ? 3 : 2); ++usr) {
                 UndrivenVarEntry* entryp = getEntryp(varrefp->varp(), usr);
                 int lsb = constp->toUInt();
-                if (m_inBBox || varrefp->lvalue()) {
+                if (m_inBBox || varrefp->access().isWriteOrRW()) {
                     // Don't warn if already driven earlier as "a=0; if(a) a=1;" is fine.
                     if (usr == 2 && m_alwaysCombp
                         && entryp->isUsedNotDrivenBit(lsb, nodep->width())) {
@@ -327,7 +327,8 @@ private:
                     }
                     entryp->drivenBit(lsb, nodep->width());
                 }
-                if (m_inBBox || !varrefp->lvalue()) entryp->usedBit(lsb, nodep->width());
+                if (m_inBBox || !varrefp->access().isWriteOrRW())
+                    entryp->usedBit(lsb, nodep->width());
             }
         } else {
             // else other varrefs handled as unknown mess in AstVarRef
@@ -336,7 +337,7 @@ private:
     }
     virtual void visit(AstNodeVarRef* nodep) override {
         // Any variable
-        if (nodep->lvalue()
+        if (nodep->access().isWriteOrRW()
             && !VN_IS(nodep, VarXRef)) {  // Ignore interface variables and similar ugly items
             if (m_inProcAssign && !nodep->varp()->varType().isProcAssignable()
                 && !nodep->varp()->isDeclTyped()  //
@@ -355,16 +356,16 @@ private:
         }
         for (int usr = 1; usr < (m_alwaysCombp ? 3 : 2); ++usr) {
             UndrivenVarEntry* entryp = getEntryp(nodep->varp(), usr);
-            bool fdrv = nodep->lvalue()
+            bool fdrv = nodep->access().isWriteOrRW()
                         && nodep->varp()->attrFileDescr();  // FD's are also being read from
-            if (m_inBBox || nodep->lvalue()) {
+            if (m_inBBox || nodep->access().isWriteOrRW()) {
                 if (usr == 2 && m_alwaysCombp && entryp->isUsedNotDrivenAny()) {
                     UINFO(9, " Full bus.  Entryp=" << cvtToHex(entryp) << endl);
                     warnAlwCombOrder(nodep);
                 }
                 entryp->drivenWhole();
             }
-            if (m_inBBox || !nodep->lvalue() || fdrv) entryp->usedWhole();
+            if (m_inBBox || nodep->access().isReadOrRW() || fdrv) entryp->usedWhole();
         }
     }
 
