@@ -28,11 +28,10 @@
 class VlcBuckets {
 private:
     // MEMBERS
-    vluint64_t* m_datap;  ///< Pointer to first bucket (dynamically allocated)
-    vluint64_t m_dataSize;  ///< Current entries in m_datap
-    vluint64_t m_bucketsCovered;  ///< Num buckets with sufficient coverage
+    vluint64_t* m_datap = nullptr;  ///< Pointer to first bucket (dynamically allocated)
+    vluint64_t m_dataSize = 0;  ///< Current entries in m_datap
+    vluint64_t m_bucketsCovered = 0;  ///< Num buckets with sufficient coverage
 
-private:
     static inline vluint64_t covBit(vluint64_t point) { return 1ULL << (point & 63); }
     inline vluint64_t allocSize() const { return sizeof(vluint64_t) * m_dataSize / 64; }
     void allocate(vluint64_t point) {
@@ -41,10 +40,10 @@ private:
         m_dataSize *= 2;
         // UINFO(9, "Realloc "<<allocSize()<<" for "<<point<<"  "<<cvtToHex(m_datap)<<endl);
         vluint64_t* newp = static_cast<vluint64_t*>(realloc(m_datap, allocSize()));
-        if (!newp) {
+        if (VL_UNCOVERABLE(!newp)) {
             // cppcheck-suppress doubleFree  // cppcheck 1.90 bug - realloc doesn't free on fail
-            free(m_datap);
-            v3fatal("Out of memory increasing buckets");
+            free(m_datap);  // LCOV_EXCL_LINE
+            v3fatal("Out of memory increasing buckets");  // LCOV_EXCL_LINE
         }
         m_datap = newp;
         for (vluint64_t i = oldsize; i < m_dataSize; i += 64) m_datap[i / 64] = 0;
@@ -52,15 +51,10 @@ private:
 
 public:
     // CONSTRUCTORS
-    VlcBuckets() {
-        m_dataSize = 0;
-        m_datap = NULL;
-        m_bucketsCovered = 0;
-        allocate(1024);
-    }
+    VlcBuckets() { allocate(1024); }
     ~VlcBuckets() {
         m_dataSize = 0;
-        VL_DO_CLEAR(free(m_datap), m_datap = NULL);
+        VL_DO_CLEAR(free(m_datap), m_datap = nullptr);
     }
 
     // ACCESSORS
