@@ -1,3 +1,7 @@
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2020 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
+
 // Test defines
 // Generated header
 #include "Vt_clk_inp_init.h"
@@ -46,7 +50,7 @@ void oneTest(int seed) {
     }
 
     topp->final();
-    delete topp; VL_DANGLING(topp);
+    VL_DO_DANGLING(delete topp, topp);
 }
 
 int main(int argc, char** argv, char** env) {
@@ -55,9 +59,7 @@ int main(int argc, char** argv, char** env) {
     // Verilated::debug(1);
 #endif
 
-    for (int seed = 123; seed < 133; ++seed) {
-        oneTest(seed);
-    }
+    for (int seed = 123; seed < 133; ++seed) oneTest(seed);
 
     return 0;
 }
