@@ -13,6 +13,7 @@
 #include <cstdlib>
 #include <cstring>
 
+// clang-format off
 #if defined(NCSC)
 // Used by NC's svdpi.h to pick up svLogicVecVal with _.aval and _.bval fields,
 // rather than the IEEE 1800-2005 version which has _.a and _.b fields.
@@ -46,6 +47,7 @@ typedef uint64_t sv_longint_unsigned_t;
 #else
 # error "Unknown simulator for DPI test"
 #endif
+// clang-format on
 
 //======================================================================
 // Implementations of imported functions
@@ -69,9 +71,7 @@ void check_bvals(const svLogicVecVal* v, unsigned n) {
 
 void set_bvals(svLogicVecVal* v, unsigned n);
 void set_bvals(svLogicVecVal* v, unsigned n) {
-    for (unsigned i = 0; i < n; i++) {
-        v[i].bval = 0;
-    }
+    for (unsigned i = 0; i < n; i++) v[i].bval = 0;
 }
 
 // Basic types as per IEEE 1800-2017 35.5.6
