@@ -16,40 +16,53 @@
 
 //======================================================================
 
+// clang-format off
 #if defined(VERILATOR)
 # include "Vt_dpi_open__Dpi.h"
 #elif defined(VCS)
 # include "../vc_hdrs.h"
 #elif defined(NC)
 # define NEED_EXTERNS
+// #elif defined(MS)
+// # define NEED_EXTERNS
 #else
 # error "Unknown simulator for DPI test"
 #endif
+// clang-format on
 
 #ifdef NEED_EXTERNS
 extern "C" {
-    // If get ncsim: *F,NOFDPI: Function {foo} not found in default libdpi.
-    // Then probably forgot to list a function here.
+// If get ncsim: *F,NOFDPI: Function {foo} not found in default libdpi.
+// Then probably forgot to list a function here.
 
-    extern void dpii_unused(const svOpenArrayHandle u);
+extern void dpii_unused(const svOpenArrayHandle u);
 
-    extern void dpii_open_p0_u1(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_p1_u0(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_p1_u1(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_p1_u2(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_p1_u3(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_pw_u0(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_pw_u1(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_pw_u2(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_pw_u3(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_p0_u1(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_p1_u0(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_p1_u1(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_p1_u2(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_p1_u3(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_pw_u0(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_pw_u1(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_pw_u2(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
+extern void dpii_open_pw_u3(int c, int p, int u, const svOpenArrayHandle i,
+                            const svOpenArrayHandle o);
 
-    extern void dpii_open_bit(const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_byte(const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_int(const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_integer(const svOpenArrayHandle i, const svOpenArrayHandle o);
-    extern void dpii_open_logic(const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_bit(const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_byte(const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_int(const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_integer(const svOpenArrayHandle i, const svOpenArrayHandle o);
+extern void dpii_open_logic(const svOpenArrayHandle i, const svOpenArrayHandle o);
 
-    extern int dpii_failure();
+extern int dpii_failure();
 }
 #endif
 
@@ -79,11 +92,13 @@ extern "C" {
 int failure = 0;
 int dpii_failure() { return failure; }
 
+// clang-format off
 #ifdef _WIN32
 # define T_PRI64 "I64"
 #else  // Linux or compliant Unix flavors
 # define T_PRI64 "ll"
 #endif
+// clang-format on
 
 #define CHECK_RESULT_HEX(got, exp) \
     do { \
@@ -94,16 +109,27 @@ int dpii_failure() { return failure; }
         } \
     } while (0)
 
+#define CHECK_RESULT_HEX_NE(got, exp) \
+    do { \
+        if ((got) == (exp)) { \
+            std::cout << std::dec << "%Error: " << __FILE__ << ":" << __LINE__ << std::hex \
+                      << ": GOT=" << (got) << "   EXP!=" << (exp) << std::endl; \
+            failure = __LINE__; \
+        } \
+    } while (0)
+
 void dpii_unused(const svOpenArrayHandle u) {}
 
 void _dpii_all(int c, int p, int u, const svOpenArrayHandle i, const svOpenArrayHandle o) {
 #ifdef TEST_VERBOSE
-    printf("-:%s:%d: For case c=%d p=%d u=%d  data=%p\n",
+    printf("-:%s:%d: For case c=%d p=%d u=%d  data=%p\n",  //
            __FILE__, __LINE__, c, p, u, svGetArrayPtr(i));
 #endif
     (void)svGetArrayPtr(i);
+#ifndef NC
     // NC always returns zero and warns
-    //(void)svSizeOfArray(i);
+    (void)svSizeOfArray(i);
+#endif
 #ifndef VCS  // VCS does not support dimension 0 query
     if (p) {
         int d = 0;
@@ -222,8 +248,29 @@ void dpii_open_pw_u3(int c, int p, int u, const svOpenArrayHandle i, const svOpe
 }
 
 void dpii_open_bit(const svOpenArrayHandle i, const svOpenArrayHandle o) {}
-void dpii_open_byte(const svOpenArrayHandle i, const svOpenArrayHandle o) {}
-void dpii_open_int(const svOpenArrayHandle i, const svOpenArrayHandle o) {}
+
+void dpii_open_byte(const svOpenArrayHandle i, const svOpenArrayHandle o) {
+    intptr_t arrPtr = (intptr_t)svGetArrayPtr(i);
+    CHECK_RESULT_HEX_NE(arrPtr, 0);  // All the arrays should actually exist
+#ifndef NC
+    // NC always returns zero and warns
+    int sizeInputOfArray = svSizeOfArray(i);
+    CHECK_RESULT_HEX_NE(sizeInputOfArray, 0);  // None of the test cases have zero size
+    CHECK_RESULT_HEX_NE(svDimensions(i), 0);  // All the test cases are unpacked arrays
+#endif
+}
+
+void dpii_open_int(const svOpenArrayHandle i, const svOpenArrayHandle o) {
+    intptr_t arrPtr = (intptr_t)svGetArrayPtr(i);
+    CHECK_RESULT_HEX_NE(arrPtr, 0);  // All the arrays should actually exist
+#ifndef NC
+    // NC always returns zero and warns
+    int sizeInputOfArray = svSizeOfArray(i);
+    CHECK_RESULT_HEX_NE(sizeInputOfArray, 0);  // None of the test cases have zero size
+    CHECK_RESULT_HEX_NE(svDimensions(i), 0);  // All the test cases are unpacked arrays
+#endif
+}
+
 void dpii_open_integer(const svOpenArrayHandle i, const svOpenArrayHandle o) {}
 void dpii_open_logic(const svOpenArrayHandle i, const svOpenArrayHandle o) {}
 
