@@ -16,6 +16,7 @@
 
 //======================================================================
 
+// clang-format off
 #if defined(VERILATOR)
 # include "Vt_embed1__Dpi.h"
 #elif defined(VCS)
@@ -25,15 +26,16 @@
 #else
 # error "Unknown simulator for DPI test"
 #endif
+// clang-format on
 
 #include "verilated.h"
 
 #ifdef NEED_EXTERNS
 extern "C" {
-    extern void t_embed_child_initial();
-    extern void t_embed_child_final();
-    extern void t_embed_child_eval();
-    extern void t_embed_child_io_eval();  // TODO real function params here
+extern void t_embed_child_initial();
+extern void t_embed_child_final();
+extern void t_embed_child_eval();
+extern void t_embed_child_io_eval();  // TODO real function params here
 }
 #endif
 
@@ -80,20 +82,14 @@ void t_embed_child_eval() {
     __modelp->eval();
 }
 
-void t_embed_child_io_eval(unsigned char clk,
-                           unsigned char bit_in,
-                           const svBitVecVal* vec_in,
-                           const svBitVecVal* wide_in,
-                           unsigned char is_ref,
-                           unsigned char* bit_out,
-                           svBitVecVal* vec_out,
-                           svBitVecVal* wide_out,
+void t_embed_child_io_eval(unsigned char clk, unsigned char bit_in, const svBitVecVal* vec_in,
+                           const svBitVecVal* wide_in, unsigned char is_ref,
+                           unsigned char* bit_out, svBitVecVal* vec_out, svBitVecVal* wide_out,
                            unsigned char* did_init_out) {
     VL_DEBUG_IF(VL_PRINTF("    t_embed1_child_io_eval\n"););
     Vt_embed1_child* __modelp = __get_modelp();
-    VL_DEBUG_IF(VL_PRINTF("[%0ld]      in clk=%x b=%x V=%x R=%x\n",
-                          (long int) (VL_TIME_Q()), clk, bit_in, vec_in[0],
-                          is_ref););
+    VL_DEBUG_IF(VL_PRINTF("[%0ld]      in clk=%x b=%x V=%x R=%x\n",  //
+                          (long int)(VL_TIME_Q()), clk, bit_in, vec_in[0], is_ref););
     __modelp->clk = clk;
     __modelp->bit_in = bit_in;
     __modelp->vec_in = vec_in[0];
@@ -114,7 +110,6 @@ void t_embed_child_io_eval(unsigned char clk,
     wide_out[2] = __modelp->wide_out[2];
     wide_out[3] = __modelp->wide_out[3];
     *did_init_out = __modelp->did_init_out;
-    VL_DEBUG_IF(VL_PRINTF("[%0ld] out b=%x V=%x DI=%x\n",
-                          (long int)(VL_TIME_Q()), *bit_out, *vec_out,
-                          *did_init_out););
+    VL_DEBUG_IF(VL_PRINTF("[%0ld] out b=%x V=%x DI=%x\n",  //
+                          (long int)(VL_TIME_Q()), *bit_out, *vec_out, *did_init_out););
 }
