@@ -48,22 +48,22 @@ int main()
 #endif
 
     // loop through every possibility and check the result
+// clang-format off
 #ifdef SYSTEMC_VERSION
     sc_start(1, SC_NS);
-#  define ASSIGN(s,v) s.write(v)
-#  define READ(s) s.read()
+# define ASSIGN(s, v) s.write(v)
+# define READ(s) s.read()
 #else
     tb->eval();
-#  define ASSIGN(s,v) tb->s = (v)
-#  define READ(s) tb->s
+# define ASSIGN(s, v) tb->s = (v)
+# define READ(s) tb->s
 #endif
+    // clang-format on
 
     ASSIGN(i3, 13);
     for (int i = 0; i < 4; i++) {
         ASSIGN(i34[i], i);
-        for (int j = 0; j < 5; j++) {
-            ASSIGN(i345[i][j], i * 8 + j);
-        }
+        for (int j = 0; j < 5; j++) ASSIGN(i345[i][j], i * 8 + j);
     }
 
 #ifdef SYSTEMC_VERSION
@@ -75,9 +75,7 @@ int main()
     check("o3", READ(o3), 13);
     for (int i = 0; i < 4; i++) {
         check("o34", READ(o34[i]), i);
-        for (int j = 0; j < 5; j++) {
-            check("o345", READ(o345[i][j]), i * 8 + j);
-        }
+        for (int j = 0; j < 5; j++) check("o345", READ(o345[i][j]), i * 8 + j);
     }
 
     if (pass) {
