@@ -2,10 +2,11 @@
 //
 // This file ONLY is placed into the Public Domain, for any use,
 // without warranty.
+// SPDX-License-Identifier: CC0-1.0
 
 #include VM_PREFIX_INCLUDE
 
-VM_PREFIX* tb = NULL;
+VM_PREFIX* tb = nullptr;
 bool pass = true;
 
 double sc_time_stamp() { return 0; }
@@ -20,12 +21,6 @@ int main()
     tb = new VM_PREFIX("tb");
 
     // Just a constructor test
-    bool pass = true;
-
-    if (pass) {
-        VL_PRINTF("*-* All Finished *-*\n");
-    } else {
-        vl_fatal(__FILE__, __LINE__, "top", "Unexpected results from test\n");
-    }
+    VL_PRINTF("*-* All Finished *-*\n");
     return 0;
 }
