@@ -1,13 +1,13 @@
+// DESCRIPTION: Verilator: Verilog Test module
+//
 // This file ONLY is placed into the Public Domain, for any use,
 // without warranty, 2013 by Ted Campbell.
+// SPDX-License-Identifier: CC0-1.0
 
 #include "Vt_order_multidriven.h"
 #include "verilated.h"
 #include "verilated_vcd_c.h"
 
-#define STRINGIFY(x) STRINGIFY2(x)
-#define STRINGIFY2(x) #x
-
 Vt_order_multidriven* vcore;
 VerilatedVcdC* vcd;
 vluint64_t vtime;
@@ -46,13 +46,14 @@ int main() {
     vcd = new VerilatedVcdC;
 
     vcore->trace(vcd, 99);
-    vcd->open(STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
+    vcd->open(VL_STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
 
     vcore->i_clk_wr = 0;
     vcore->i_clk_rd = 0;
 
-    for (int i = 0; i < 256; ++i)
+    for (int i = 0; i < 256; ++i) {  //
         cycle();
+    }
 
     vcd->close();
     printf("*-* All Finished *-*\n");
