@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
@@ -15,9 +15,9 @@ compile(
     expect_filename => $Self->{golden_filename},
     );
 
-#execute(
-#    check_finished => 1,
-#    );
+execute(
+    check_finished => 1,
+    ) if !$Self->{vlt_all};
 
 ok(1);
 1;
