@@ -2,15 +2,23 @@
 //
 // DESCRIPTION: Verilator: Verilog Test module
 //
-// This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2008 by Wilson Snyder.
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2008 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
 
 #include <verilated.h>
 #include <verilated_vcd_c.h>
 
-#include "Vt_trace_public_sig.h"
-#include "Vt_trace_public_sig_t.h"
-#include "Vt_trace_public_sig_glbl.h"
+// clang-format off
+#include VM_PREFIX_INCLUDE
+#ifdef T_TRACE_PUBLIC_SIG_VLT
+# include "Vt_trace_public_sig_vlt_t.h"
+# include "Vt_trace_public_sig_vlt_glbl.h"
+#else
+# include "Vt_trace_public_sig_t.h"
+# include "Vt_trace_public_sig_glbl.h"
+#endif
+// clang-format on
 
 unsigned long long main_time = 0;
 double sc_time_stamp() { return (double)main_time; }
@@ -18,7 +26,7 @@ double sc_time_stamp() { return (double)main_time; }
 const unsigned long long dt_2 = 3;
 
 int main(int argc, char** argv, char** env) {
-    Vt_trace_public_sig* top = new Vt_trace_public_sig("top");
+    VM_PREFIX* top = new VM_PREFIX("top");
 
     Verilated::debug(0);
     Verilated::traceEverOn(true);
