@@ -1,15 +1,14 @@
 // -*- mode: C++; c-file-style: "cc-mode" -*-
 //
 // This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2008 by Lane Brooks
+// without warranty, 2008 by Lane Brooks.
+// SPDX-License-Identifier: CC0-1.0
 
 #include VM_PREFIX_INCLUDE
 
-VM_PREFIX* tb = NULL;
+VM_PREFIX* tb = nullptr;
 
-double sc_time_stamp() {
-    return 0;
-}
+double sc_time_stamp() { return 0; }
 
 bool check() {
     bool pass;
@@ -20,7 +19,7 @@ bool check() {
     bool verbose = false;
 #endif
 
-    if(tb->W == c && tb->X == c && tb->Y == c && tb->Z == c) {
+    if (tb->W == c && tb->X == c && tb->Y == c && tb->Z == c) {
         pass = true;
         if (verbose) printf("-  pass: ");
     } else {
@@ -29,8 +28,8 @@ bool check() {
         printf("%%E-FAIL: ");
     }
     if (verbose) {
-        printf("SEL=%d A=%d   got: W=%d X=%d Y=%d Z=%d  exp: WXYZ=%d\n",
-               tb->SEL, tb->A, tb->W, tb->X, tb->Y, tb->Z, c);
+        printf("SEL=%d A=%d   got: W=%d X=%d Y=%d Z=%d  exp: WXYZ=%d\n", tb->SEL, tb->A, tb->W,
+               tb->X, tb->Y, tb->Z, c);
     }
     return pass;
 }
@@ -42,20 +41,18 @@ int main() {
     tb = new VM_PREFIX("tb");
 
     // loop through every possibility and check the result
-    for (tb->SEL=0; tb->SEL<2; tb->SEL++) {
-        for (tb->A=0; tb->A<4; tb->A++) {
+    for (tb->SEL = 0; tb->SEL < 2; tb->SEL++) {
+        for (tb->A = 0; tb->A < 4; tb->A++) {
             tb->eval();
-            if(!check()) {
-                pass =false;
-            }
+            if (!check()) { pass = false; }
         }
     }
 
-    if(pass) {
+    if (pass) {
         VL_PRINTF("*-* All Finished *-*\n");
         tb->final();
     } else {
-        vl_fatal(__FILE__,__LINE__,"top", "Unexpected results from tristate test\n");
+        vl_fatal(__FILE__, __LINE__, "top", "Unexpected results from tristate test\n");
     }
     return 0;
 }
