@@ -30,7 +30,6 @@
 #include <cstdio>
 #include <cstring>
 #include <iostream>
-using namespace std;
 
 #include "TestSimulator.h"
 #include "TestVpi.h"
@@ -60,15 +59,15 @@ unsigned int main_time = 0;
 // Use cout to avoid issues with %d/%lx etc
 #define CHECK_RESULT(got, exp) \
     if ((got) != (exp)) { \
-        cout << dec << "%Error: " << FILENM << ":" << __LINE__ << ": GOT = " << (got) \
-             << "   EXP = " << (exp) << endl; \
+        std::cout << std::dec << "%Error: " << FILENM << ":" << __LINE__ << ": GOT = " << (got) \
+                  << "   EXP = " << (exp) << std::endl; \
         return __LINE__; \
     }
 
 #define CHECK_RESULT_HEX(got, exp) \
     if ((got) != (exp)) { \
-        cout << dec << "%Error: " << FILENM << ":" << __LINE__ << hex << ": GOT = " << (got) \
-             << "   EXP = " << (exp) << endl; \
+        std::cout << std::dec << "%Error: " << FILENM << ":" << __LINE__ << std::hex \
+                  << ": GOT = " << (got) << "   EXP = " << (exp) << std::endl; \
         return __LINE__; \
     }
 
@@ -83,13 +82,12 @@ unsigned int main_time = 0;
 
 int _mon_check_range(TestVpiHandle& handle, int size, int left, int right) {
     TestVpiHandle iter_h, left_h, right_h;
-    s_vpi_value value = {.format = vpiIntVal, .value = {.integer = 0}};
+    s_vpi_value value;
+    value.format = vpiIntVal;
+    value.value.integer = 0;
     // check size of object
     int vpisize = vpi_get(vpiSize, handle);
     CHECK_RESULT(vpisize, size);
-    // check size of range
-    vpisize = vpi_get(vpiSize, handle);
-    CHECK_RESULT(vpisize, size);
     // check left hand side of range
     left_h = vpi_handle(vpiLeftRange, handle);
     CHECK_RESULT_NZ(left_h);
@@ -110,9 +108,13 @@ int _mon_check_range(TestVpiHandle& handle, int size, int left, int right) {
 
 int _mon_check_memory() {
     int cnt;
-    TestVpiHandle mem_h, lcl_h;
+    TestVpiHandle mem_h, lcl_h, side_h;
     vpiHandle iter_h;  // Icarus does not like auto free of iterator handles
-    s_vpi_value value = {.format = vpiIntVal, .value = {.integer = 0}};
+    s_vpi_value value;
+    value.format = vpiIntVal;
+    value.value.integer = 0;
+    s_vpi_error_info e;
+
     vpi_printf((PLI_BYTE8*)"Check memory vpi ...\n");
     mem_h = vpi_handle_by_name((PLI_BYTE8*)TestSimulator::rooted("mem0"), NULL);
     CHECK_RESULT_NZ(mem_h);
@@ -158,6 +160,25 @@ int _mon_check_memory() {
     CHECK_RESULT(should_be_NULL, 0);
     should_be_NULL = vpi_handle(vpiScope, iter_h);
     CHECK_RESULT(should_be_NULL, 0);
+
+    // check vpiRange
+    iter_h = vpi_iterate(vpiRange, mem_h);
+    CHECK_RESULT_NZ(iter_h);
+    lcl_h = vpi_scan(iter_h);
+    CHECK_RESULT_NZ(lcl_h);
+    side_h = vpi_handle(vpiLeftRange, lcl_h);
+    CHECK_RESULT_NZ(side_h);
+    vpi_get_value(side_h, &value);
+    CHECK_RESULT(value.value.integer, 16);
+    side_h = vpi_handle(vpiRightRange, lcl_h);
+    CHECK_RESULT_NZ(side_h);
+    vpi_get_value(side_h, &value);
+    CHECK_RESULT(value.value.integer, 1);
+
+    // check writing to vpiConstant
+    vpi_put_value(side_h, &value, NULL, vpiNoDelay);
+    CHECK_RESULT_NZ(vpi_chk_error(&e));
+
     return 0;  // Ok
 }
 
@@ -190,8 +211,7 @@ static s_vpi_systf_data vpi_systf_data[] = {{vpiSysFunc, vpiIntFunc, (PLI_BYTE8*
 void vpi_compat_bootstrap(void) {
     p_vpi_systf_data systf_data_p;
     systf_data_p = &(vpi_systf_data[0]);
-    while (systf_data_p->type != 0)
-        vpi_register_systf(systf_data_p++);
+    while (systf_data_p->type != 0) vpi_register_systf(systf_data_p++);
 }
 
 // icarus entry
